# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_enrichment_coverage_response import ReportingEnrichmentCoverageResponse

class TestReportingEnrichmentCoverageResponse(unittest.TestCase):
    """ReportingEnrichmentCoverageResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingEnrichmentCoverageResponse:
        """Test ReportingEnrichmentCoverageResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingEnrichmentCoverageResponse`
        """
        model = ReportingEnrichmentCoverageResponse()
        if include_optional:
            return ReportingEnrichmentCoverageResponse(
                by_client = [
                    neurograph.v1.models.reporting/client_enrichment_coverage.reporting.ClientEnrichmentCoverage(
                        account_uid = '', 
                        client_uid = '', 
                        enriched_count = 56, 
                        enriched_percentage = 1.337, 
                        not_enriched_count = 56, 
                        total_products = 56, )
                    ],
                cached = True,
                error = '',
                query_time_ms = 56,
                summary = neurograph.v1.models.reporting/enrichment_coverage_summary.reporting.EnrichmentCoverageSummary(
                    overall_enriched_percent = 1.337, 
                    total_clients = 56, 
                    total_enriched = 56, 
                    total_not_enriched = 56, 
                    total_products = 56, )
            )
        else:
            return ReportingEnrichmentCoverageResponse(
        )
        """

    def testReportingEnrichmentCoverageResponse(self):
        """Test ReportingEnrichmentCoverageResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_gamma_design_settings import OrganizationsGammaDesignSettings

class TestOrganizationsGammaDesignSettings(unittest.TestCase):
    """OrganizationsGammaDesignSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsGammaDesignSettings:
        """Test OrganizationsGammaDesignSettings
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsGammaDesignSettings`
        """
        model = OrganizationsGammaDesignSettings()
        if include_optional:
            return OrganizationsGammaDesignSettings(
                blocks = neurograph.v1.models.organizations/gamma_block_settings.organizations.GammaBlockSettings(
                    block_border = 56, 
                    block_fill = 56, 
                    block_fill_color = '', 
                    block_shadow = 56, ),
                buttons = neurograph.v1.models.organizations/gamma_button_settings.organizations.GammaButtonSettings(
                    button_color = '', 
                    button_shape = 56, 
                    link_color = '', ),
                cards = neurograph.v1.models.organizations/gamma_card_settings.organizations.GammaCardSettings(
                    accent_image_shape = 56, 
                    card_border = 56, 
                    card_border_color = '', 
                    card_shadow = 56, 
                    card_transparency = 56, 
                    roundness = 56, )
            )
        else:
            return OrganizationsGammaDesignSettings(
        )
        """

    def testOrganizationsGammaDesignSettings(self):
        """Test OrganizationsGammaDesignSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from neurograph.v1.models.client_kpi import ClientKpi
from neurograph.v1.models.client_match_criteria_row_in_db import ClientMatchCriteriaRowInDb
from neurograph.v1.models.client_persona_factor import ClientPersonaFactor
from neurograph.v1.models.client_persona_insight import ClientPersonaInsight
from neurograph.v1.models.client_persona_personality_trait import ClientPersonaPersonalityTrait
from neurograph.v1.models.client_supplemental_prompt import ClientSupplementalPrompt
from typing import Optional, Set
from typing_extensions import Self

class ClientPersona(BaseModel):
    """
    ClientPersona
    """ # noqa: E501
    age: Optional[Union[StrictFloat, StrictInt]] = None
    description: Optional[StrictStr] = None
    factors: Optional[List[ClientPersonaFactor]] = None
    female: Optional[Union[StrictFloat, StrictInt]] = None
    id: Optional[StrictStr] = None
    income: Optional[StrictStr] = None
    insights: Optional[List[ClientPersonaInsight]] = None
    is_active: Optional[StrictBool] = None
    kpis: Optional[List[ClientKpi]] = None
    male: Optional[Union[StrictFloat, StrictInt]] = None
    match_criteria: Optional[List[ClientMatchCriteriaRowInDb]] = None
    metadata: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    persona_seed_id: Optional[StrictStr] = None
    personality_background: Optional[StrictStr] = None
    personality_first_name: Optional[StrictStr] = None
    personality_gender: Optional[StrictStr] = None
    personality_img_url: Optional[StrictStr] = None
    personality_last_name: Optional[StrictStr] = None
    personality_quote: Optional[StrictStr] = None
    personality_traits: Optional[List[ClientPersonaPersonalityTrait]] = None
    personality_video_url: Optional[StrictStr] = None
    positioning_statement: Optional[StrictStr] = None
    seed_uid: Optional[StrictStr] = None
    summary_detail: Optional[StrictStr] = None
    summary_headline: Optional[StrictStr] = None
    supplemental_prompts: Optional[List[ClientSupplementalPrompt]] = None
    tag: Optional[StrictStr] = None
    ts_created: Optional[StrictInt] = None
    ts_updated: Optional[StrictInt] = None
    value: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["age", "description", "factors", "female", "id", "income", "insights", "is_active", "kpis", "male", "match_criteria", "metadata", "name", "persona_seed_id", "personality_background", "personality_first_name", "personality_gender", "personality_img_url", "personality_last_name", "personality_quote", "personality_traits", "personality_video_url", "positioning_statement", "seed_uid", "summary_detail", "summary_headline", "supplemental_prompts", "tag", "ts_created", "ts_updated", "value"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ClientPersona from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in factors (list)
        _items = []
        if self.factors:
            for _item_factors in self.factors:
                if _item_factors:
                    _items.append(_item_factors.to_dict())
            _dict['factors'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in insights (list)
        _items = []
        if self.insights:
            for _item_insights in self.insights:
                if _item_insights:
                    _items.append(_item_insights.to_dict())
            _dict['insights'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in kpis (list)
        _items = []
        if self.kpis:
            for _item_kpis in self.kpis:
                if _item_kpis:
                    _items.append(_item_kpis.to_dict())
            _dict['kpis'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in match_criteria (list)
        _items = []
        if self.match_criteria:
            for _item_match_criteria in self.match_criteria:
                if _item_match_criteria:
                    _items.append(_item_match_criteria.to_dict())
            _dict['match_criteria'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in personality_traits (list)
        _items = []
        if self.personality_traits:
            for _item_personality_traits in self.personality_traits:
                if _item_personality_traits:
                    _items.append(_item_personality_traits.to_dict())
            _dict['personality_traits'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in supplemental_prompts (list)
        _items = []
        if self.supplemental_prompts:
            for _item_supplemental_prompts in self.supplemental_prompts:
                if _item_supplemental_prompts:
                    _items.append(_item_supplemental_prompts.to_dict())
            _dict['supplemental_prompts'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ClientPersona from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "age": obj.get("age"),
            "description": obj.get("description"),
            "factors": [ClientPersonaFactor.from_dict(_item) for _item in obj["factors"]] if obj.get("factors") is not None else None,
            "female": obj.get("female"),
            "id": obj.get("id"),
            "income": obj.get("income"),
            "insights": [ClientPersonaInsight.from_dict(_item) for _item in obj["insights"]] if obj.get("insights") is not None else None,
            "is_active": obj.get("is_active"),
            "kpis": [ClientKpi.from_dict(_item) for _item in obj["kpis"]] if obj.get("kpis") is not None else None,
            "male": obj.get("male"),
            "match_criteria": [ClientMatchCriteriaRowInDb.from_dict(_item) for _item in obj["match_criteria"]] if obj.get("match_criteria") is not None else None,
            "metadata": obj.get("metadata"),
            "name": obj.get("name"),
            "persona_seed_id": obj.get("persona_seed_id"),
            "personality_background": obj.get("personality_background"),
            "personality_first_name": obj.get("personality_first_name"),
            "personality_gender": obj.get("personality_gender"),
            "personality_img_url": obj.get("personality_img_url"),
            "personality_last_name": obj.get("personality_last_name"),
            "personality_quote": obj.get("personality_quote"),
            "personality_traits": [ClientPersonaPersonalityTrait.from_dict(_item) for _item in obj["personality_traits"]] if obj.get("personality_traits") is not None else None,
            "personality_video_url": obj.get("personality_video_url"),
            "positioning_statement": obj.get("positioning_statement"),
            "seed_uid": obj.get("seed_uid"),
            "summary_detail": obj.get("summary_detail"),
            "summary_headline": obj.get("summary_headline"),
            "supplemental_prompts": [ClientSupplementalPrompt.from_dict(_item) for _item in obj["supplemental_prompts"]] if obj.get("supplemental_prompts") is not None else None,
            "tag": obj.get("tag"),
            "ts_created": obj.get("ts_created"),
            "ts_updated": obj.get("ts_updated"),
            "value": obj.get("value")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.personas_seed_get_many_response import PersonasSeedGetManyResponse

class TestPersonasSeedGetManyResponse(unittest.TestCase):
    """PersonasSeedGetManyResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PersonasSeedGetManyResponse:
        """Test PersonasSeedGetManyResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PersonasSeedGetManyResponse`
        """
        model = PersonasSeedGetManyResponse()
        if include_optional:
            return PersonasSeedGetManyResponse(
                data = [
                    neurograph.v1.models.personas/seed.personas.Seed(
                        client_id = 'cli_5678', 
                        error = '', 
                        id = 'per_1234', 
                        is_active = True, 
                        ts_created = 56, 
                        uid = 'strong-gym-guy', )
                    ],
                error = '',
                query_limit = 56,
                query_offset = 56,
                total_rows = 56
            )
        else:
            return PersonasSeedGetManyResponse(
        )
        """

    def testPersonasSeedGetManyResponse(self):
        """Test PersonasSeedGetManyResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from neurograph.v1.models.reporting_client_breakdown import ReportingClientBreakdown
from neurograph.v1.models.reporting_date_range import ReportingDateRange
from neurograph.v1.models.reporting_org_breakdown import ReportingOrgBreakdown
from neurograph.v1.models.reporting_portfolio_metrics import ReportingPortfolioMetrics
from typing import Optional, Set
from typing_extensions import Self

class ReportingPortfolioActivityResponse(BaseModel):
    """
    ReportingPortfolioActivityResponse
    """ # noqa: E501
    by_client: Optional[List[ReportingClientBreakdown]] = None
    by_org: Optional[List[ReportingOrgBreakdown]] = None
    cached: Optional[StrictBool] = None
    date_range: Optional[ReportingDateRange] = None
    error: Optional[StrictStr] = None
    portfolio: Optional[ReportingPortfolioMetrics] = None
    query_time_ms: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["by_client", "by_org", "cached", "date_range", "error", "portfolio", "query_time_ms"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReportingPortfolioActivityResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in by_client (list)
        _items = []
        if self.by_client:
            for _item_by_client in self.by_client:
                if _item_by_client:
                    _items.append(_item_by_client.to_dict())
            _dict['by_client'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in by_org (list)
        _items = []
        if self.by_org:
            for _item_by_org in self.by_org:
                if _item_by_org:
                    _items.append(_item_by_org.to_dict())
            _dict['by_org'] = _items
        # override the default output from pydantic by calling `to_dict()` of date_range
        if self.date_range:
            _dict['date_range'] = self.date_range.to_dict()
        # override the default output from pydantic by calling `to_dict()` of portfolio
        if self.portfolio:
            _dict['portfolio'] = self.portfolio.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReportingPortfolioActivityResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "by_client": [ReportingClientBreakdown.from_dict(_item) for _item in obj["by_client"]] if obj.get("by_client") is not None else None,
            "by_org": [ReportingOrgBreakdown.from_dict(_item) for _item in obj["by_org"]] if obj.get("by_org") is not None else None,
            "cached": obj.get("cached"),
            "date_range": ReportingDateRange.from_dict(obj["date_range"]) if obj.get("date_range") is not None else None,
            "error": obj.get("error"),
            "portfolio": ReportingPortfolioMetrics.from_dict(obj["portfolio"]) if obj.get("portfolio") is not None else None,
            "query_time_ms": obj.get("query_time_ms")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_personas_response import ClientPersonasResponse

class TestClientPersonasResponse(unittest.TestCase):
    """ClientPersonasResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientPersonasResponse:
        """Test ClientPersonasResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientPersonasResponse`
        """
        model = ClientPersonasResponse()
        if include_optional:
            return ClientPersonasResponse(
                data = [
                    neurograph.v1.models.client/persona.client.Persona(
                        age = 1.337, 
                        description = '', 
                        factors = [
                            neurograph.v1.models.client/persona_factor.client.PersonaFactor(
                                detail = '', 
                                display = '', 
                                id = 56, 
                                name = '', 
                                persona_instance_id = '', 
                                summary = '', 
                                value = 56, )
                            ], 
                        female = 1.337, 
                        id = '', 
                        income = '', 
                        insights = [
                            neurograph.v1.models.client/persona_insight.client.PersonaInsight(
                                data = neurograph.v1.models.data.data(), 
                                id = 56, 
                                key = '', 
                                persona_instance_id = 56, )
                            ], 
                        is_active = True, 
                        kpis = [
                            neurograph.v1.models.client/kpi.client.Kpi(
                                id = 56, 
                                name = '', 
                                persona_instance_id = '', 
                                value = '', )
                            ], 
                        male = 1.337, 
                        match_criteria = [
                            neurograph.v1.models.client/match_criteria_row_in_db.client.MatchCriteriaRowInDb(
                                concept = '', 
                                detail = '', 
                                display = '', 
                                error = '', 
                                id = 56, 
                                persona_instance_id = '', 
                                sort_order = 56, )
                            ], 
                        metadata = '', 
                        name = '', 
                        persona_seed_id = '', 
                        personality_background = '', 
                        personality_first_name = '', 
                        personality_gender = '', 
                        personality_img_url = '', 
                        personality_last_name = '', 
                        personality_quote = '', 
                        personality_traits = [
                            neurograph.v1.models.client/persona_personality_trait.client.PersonaPersonalityTrait(
                                id = 56, 
                                name = '', 
                                persona_instance_id = '', 
                                traits = [
                                    ''
                                    ], )
                            ], 
                        personality_video_url = '', 
                        positioning_statement = '', 
                        seed_uid = '', 
                        summary_detail = '', 
                        summary_headline = '', 
                        supplemental_prompts = [
                            neurograph.v1.models.client/supplemental_prompt.client.SupplementalPrompt(
                                id = '', 
                                persona_instance_id = '', 
                                persona_seed_id = '', 
                                processing_state = '', 
                                prompt = '', 
                                ts_created = 56, 
                                ts_updated = 56, )
                            ], 
                        tag = '', 
                        ts_created = 56, 
                        ts_updated = 56, 
                        value = '', )
                    ],
                error = '',
                total_rows = 56
            )
        else:
            return ClientPersonasResponse(
        )
        """

    def testClientPersonasResponse(self):
        """Test ClientPersonasResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_persona_product_affinity_response import ReportingPersonaProductAffinityResponse

class TestReportingPersonaProductAffinityResponse(unittest.TestCase):
    """ReportingPersonaProductAffinityResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingPersonaProductAffinityResponse:
        """Test ReportingPersonaProductAffinityResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingPersonaProductAffinityResponse`
        """
        model = ReportingPersonaProductAffinityResponse()
        if include_optional:
            return ReportingPersonaProductAffinityResponse(
                cached = True,
                category_performance = neurograph.v1.models.reporting/category_performance_data.reporting.CategoryPerformanceData(
                    categories = [
                        neurograph.v1.models.reporting/category_performance_row.reporting.CategoryPerformanceRow(
                            avg_spend = 1.337, 
                            category_name = '', 
                            conversion_rate = 1.337, 
                            engagement_level = '', 
                            is_top_category = True, 
                            purchases = 56, 
                            relative_performance = 1.337, )
                        ], 
                    displayed_categories = 56, 
                    total_categories = 56, ),
                category_spend = neurograph.v1.models.reporting/category_spend_data.reporting.CategorySpendData(
                    categories = [
                        ''
                        ], 
                    data = [
                        neurograph.v1.models.reporting/category_spend_week.reporting.CategorySpendWeek(
                            spend = {
                                'key' : 1.337
                                }, 
                            week = '', )
                        ], 
                    period_comparison = neurograph.v1.models.reporting/period_comparison.reporting.PeriodComparison(
                        change_percentage = 1.337, 
                        current_period_spend = 1.337, 
                        previous_period_spend = 1.337, 
                        trend = '', ), 
                    total_spend = 1.337, 
                    weeks = [
                        ''
                        ], ),
                error = '',
                meta = neurograph.v1.models.reporting/affinity_meta.reporting.AffinityMeta(
                    client_partition_key = '', 
                    client_uid = '', 
                    data_date = '', 
                    generated_at = '', 
                    organization_uid = '', 
                    persona_id = '', ),
                price_tolerance = neurograph.v1.models.reporting/price_tolerance_data.reporting.PriceToleranceData(
                    price_distribution = [
                        neurograph.v1.models.reporting/price_bucket.reporting.PriceBucket(
                            is_top_bucket = True, 
                            order_count = 56, 
                            percentage = 1.337, 
                            price_bucket = '', 
                            price_bucket_label = '', )
                        ], 
                    willingness_to_pay_premium = '', ),
                product_performance = neurograph.v1.models.reporting/product_performance_data.reporting.ProductPerformanceData(
                    products = [
                        neurograph.v1.models.reporting/product_performance_row.reporting.ProductPerformanceRow(
                            affinity_score = 1.337, 
                            affinity_tier = '', 
                            avg_spend = 1.337, 
                            conversion_rate = 1.337, 
                            engagement_score = 1.337, 
                            product_handle = '', 
                            product_name = '', 
                            product_type = '', 
                            purchases = 56, )
                        ], 
                    total_products = 56, ),
                purchase_cycle = neurograph.v1.models.reporting/purchase_cycle_data.reporting.PurchaseCycleData(
                    new_customers = neurograph.v1.models.reporting/customer_cycle_metrics.reporting.CustomerCycleMetrics(
                        count = 56, 
                        cycle_days = 56, 
                        display_value = '', 
                        median_days = 56, 
                        tiers = neurograph.v1.models.reporting/cycle_tiers.reporting.CycleTiers(
                            fast = 56, 
                            slow = 56, 
                            typical = 56, ), ), 
                    returning_customers = neurograph.v1.models.reporting/customer_cycle_metrics.reporting.CustomerCycleMetrics(
                        count = 56, 
                        cycle_days = 56, 
                        display_value = '', 
                        median_days = 56, ), 
                    summary = neurograph.v1.models.reporting/cycle_summary.reporting.CycleSummary(
                        categories = neurograph.v1.models.reporting/category_summary.reporting.CategorySummary(
                            engaged = 56, 
                            total = 56, ), 
                        last_purchase_days_ago = 56, 
                        total_customers = 56, ), ),
                purchase_timing = neurograph.v1.models.reporting/purchase_timing_data.reporting.PurchaseTimingData(
                    peak_shopping_time = '', 
                    timing_distribution = [
                        neurograph.v1.models.reporting/timing_bucket.reporting.TimingBucket(
                            is_peak = True, 
                            order_count = 56, 
                            percentage = 1.337, 
                            timing_bucket = '', )
                        ], ),
                query_time_ms = 56
            )
        else:
            return ReportingPersonaProductAffinityResponse(
        )
        """

    def testReportingPersonaProductAffinityResponse(self):
        """Test ReportingPersonaProductAffinityResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "AdminApi",
    "AuthenticationApi",
    "ClientApi",
    "ClientMetadataApi",
    "DagsterApi",
    "KnowledgeApi",
    "KnowledgeExtractApi",
    "LookupApi",
    "OrganizationApi",
    "OrganizationMetadataApi",
    "PersonaApi",
    "PixelApi",
    "ReportingApi",
    "ReportsApi",
    "SignalApi",
    "UserApi",
    "WorkbenchApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AdminPermissionResponse",
    "AdminResetPasswordRequest",
    "AdminResetPasswordResponse",
    "AdminSetPermissionRequest",
    "AdminUpsertUserRequest",
    "AdminUpsertUserResponse",
    "AdminUser",
    "AdminUserDetailResponse",
    "AdminUsersGetManyResponse",
    "AdminUsersOrgResponse",
    "AuthServiceTokenRequest",
    "AuthServiceTokenResponse",
    "AuthTestServiceTokenRequest",
    "AuthTestServiceTokenResponse",
    "AuthTestTokenResponse",
    "ClientClient",
    "ClientDeleteMetadataRequest",
    "ClientGetDetailResponse",
    "ClientGetManyResponse",
    "ClientHealthcheckCreateRequest",
    "ClientHealthcheckResponse",
    "ClientHealthcheckRollupResponse",
    "ClientInfo",
    "ClientKpi",
    "ClientMatchCriteriaRowInDb",
    "ClientMetadata",
    "ClientMetadataRequest",
    "ClientMetadataResponse",
    "ClientOrganizationBrand",
    "ClientOrganizationDetail",
    "ClientPersona",
    "ClientPersonaAssignmentStats",
    "ClientPersonaAssignmentStatsResponse",
    "ClientPersonaFactor",
    "ClientPersonaInsight",
    "ClientPersonaPersonalityTrait",
    "ClientPersonasResponse",
    "ClientProbe",
    "ClientProbeTodoRow",
    "ClientQuery",
    "ClientSlackMessageRequest",
    "ClientSlackMessageResponse",
    "ClientSupplementalPrompt",
    "ClientTriggerProbeResponse",
    "ClientURLSnapshotResponse",
    "ClientUpsertRequest",
    "ClientUpsertResponse",
    "ClientUrlRow",
    "ClientUrlSnapshotRow",
    "ClientUrlUpsertRequest",
    "ClientUrlUpsertResponse",
    "ClientUrlsResponse",
    "ClientWorkbenchConfig",
    "DagsterInfo",
    "DagsterLogCreateRequest",
    "DagsterLogCreateResponse",
    "DagsterLogGetResponse",
    "DbAccountOrganizationBrand",
    "DbClientUrl",
    "DbKnowledgeCustomer",
    "DbKnowledgeOrder",
    "DbKnowledgeProduct",
    "DbKnowledgeStore",
    "DbMyClient",
    "DbMyOrg",
    "DbPersonaFactor",
    "DbPersonaFactorCreateParams",
    "DbPersonaMatchCriterium",
    "DbPixelSnippet",
    "DbUserClientRole",
    "DbUserInDb",
    "DbUserOrgRole",
    "DbUserRole",
    "KnowledgeAssertion",
    "KnowledgeAssertionCreateRequest",
    "KnowledgeAssertionListResponse",
    "KnowledgeAssertionQuery",
    "KnowledgeAssertionResponse",
    "KnowledgeCustomerQuery",
    "KnowledgeCustomerResponse",
    "KnowledgeEnrichmentArtifact",
    "KnowledgeEnrichmentArtifactCreateRequest",
    "KnowledgeEnrichmentArtifactListResponse",
    "KnowledgeEnrichmentArtifactResponse",
    "KnowledgeEnrichmentArtifactUpdateOutputRequest",
    "KnowledgeEnrichmentArtifactUpdateStatusRequest",
    "KnowledgeEnrichmentQuery",
    "KnowledgeEntity",
    "KnowledgeEntityCreateRequest",
    "KnowledgeEntityCreateResponse",
    "KnowledgeEntityErrRow",
    "KnowledgeEntityExtra",
    "KnowledgeEntityGetManyResponse",
    "KnowledgeEntityInDb",
    "KnowledgeEntityRelations",
    "KnowledgeEntitySchema",
    "KnowledgeEntitySchemaRow",
    "KnowledgeEntitySchemaUpsertRequest",
    "KnowledgeEntitySchemasResponse",
    "KnowledgeEntitySchemasUpsertResponse",
    "KnowledgeEntityTypeResponse",
    "KnowledgeEntityTypeRow",
    "KnowledgeEntityTypeUpsertRequest",
    "KnowledgeEntityTypeUpsertRow",
    "KnowledgeEntityUpsertRequest",
    "KnowledgeEntityUpsertResponse",
    "KnowledgeIngestRawRequest",
    "KnowledgeIngestRawResponse",
    "KnowledgeIngestRawRow",
    "KnowledgeKindResponse",
    "KnowledgeOrderQuery",
    "KnowledgeOrderResponse",
    "KnowledgeProduct",
    "KnowledgeProductQuery",
    "KnowledgeProductResponse",
    "KnowledgeProductUpsertRequest",
    "KnowledgeProductUpsertResponse",
    "KnowledgeQuery",
    "KnowledgeStoreQuery",
    "KnowledgeStoreResponse",
    "LookupEnv",
    "LookupLanguage",
    "LookupLanguageResponse",
    "LookupLookupEnvironmentsResponse",
    "LookupRole",
    "LookupRolesResponse",
    "LookupState",
    "LookupStateResponse",
    "LookupStatesResponse",
    "LookupSyncSnippetsResponse",
    "LookupUid",
    "LookupUidsResponse",
    "MeMyProfileResponse",
    "OpenaiAccessibilityInfo",
    "OpenaiBrandAnalysis",
    "OpenaiBrandColors",
    "OpenaiGeneratedBrand",
    "OrganizationsApplyPresetRequest",
    "OrganizationsApplyPresetResponse",
    "OrganizationsBrand",
    "OrganizationsBrandDetailResponse",
    "OrganizationsBrandGenerationRequest",
    "OrganizationsBrandGenerationResponse",
    "OrganizationsBrandHistoryDetailResponse",
    "OrganizationsBrandHistoryItem",
    "OrganizationsBrandHistoryListResponse",
    "OrganizationsBrandRollbackRequest",
    "OrganizationsBrandRollbackResponse",
    "OrganizationsBrandUpsertRequest",
    "OrganizationsComponentConfig",
    "OrganizationsCreateRequest",
    "OrganizationsDeleteMetadataRequest",
    "OrganizationsDeleteMetadataResponse",
    "OrganizationsDetailResponse",
    "OrganizationsGammaBlockSettings",
    "OrganizationsGammaButtonSettings",
    "OrganizationsGammaCardSettings",
    "OrganizationsGammaColorSettings",
    "OrganizationsGammaDesignSettings",
    "OrganizationsGammaFontSettings",
    "OrganizationsGammaThemeRequest",
    "OrganizationsGammaThemeResponse",
    "OrganizationsGammaThemeSettings",
    "OrganizationsGenerateTokensRequest",
    "OrganizationsGenerateTokensResponse",
    "OrganizationsGenerationMetadata",
    "OrganizationsGetBrandingTokensResponse",
    "OrganizationsGetManyResponse",
    "OrganizationsMetadata",
    "OrganizationsMetadataRequest",
    "OrganizationsMetadataResponse",
    "OrganizationsOrganization",
    "OrganizationsOrganizationSetWorkbenchRequest",
    "OrganizationsOrganizationSetWorkbenchResponse",
    "OrganizationsOrganizationUpdateRequest",
    "OrganizationsPresetRecommendation",
    "OrganizationsPreviewBrandingRequest",
    "OrganizationsPreviewBrandingResponse",
    "OrganizationsRecommendPresetsResponse",
    "OrganizationsScreenshotURLRequest",
    "OrganizationsScreenshotURLResponse",
    "OrganizationsSpacingConfig",
    "OrganizationsTestAccessibilityRequest",
    "OrganizationsTestAccessibilityResponse",
    "OrganizationsThemePresetCreateRequest",
    "OrganizationsThemePresetListResponse",
    "OrganizationsThemePresetResponse",
    "OrganizationsThemePresetUpdateRequest",
    "OrganizationsTypographyConfig",
    "OrganizationsValidateBrandingRequest",
    "OrganizationsValidateBrandingResponse",
    "OrganizationsWorkbenchConfig",
    "PersonasFactorCreateRequest",
    "PersonasFactorCreateResponse",
    "PersonasFactorDeleteResponse",
    "PersonasFactorRow",
    "PersonasFactorUpdateRequest",
    "PersonasFactorUpdateResponse",
    "PersonasGetLatestPersonaInstanceRequest",
    "PersonasGetPersonaInstanceResponse",
    "PersonasInsightCreateRequest",
    "PersonasInsightCreateResponse",
    "PersonasInstanceCreateRequest",
    "PersonasInstanceCreateResponse",
    "PersonasInstanceDeleteManyRequest",
    "PersonasInstanceDeleteManyResponse",
    "PersonasInstancesResponse",
    "PersonasKpi",
    "PersonasKpiCreateRequest",
    "PersonasKpiCreateResponse",
    "PersonasKpiReqRow",
    "PersonasKpiRowInDb",
    "PersonasMatchCriteriaDeleteResponse",
    "PersonasMatchCriteriaReorderItem",
    "PersonasMatchCriteriaReorderRequest",
    "PersonasMatchCriteriaReorderResponse",
    "PersonasMatchCriteriaRequest",
    "PersonasMatchCriteriaResponse",
    "PersonasMatchCriteriaRowIn",
    "PersonasMatchCriteriaRowInDb",
    "PersonasMatchCriteriaUpdateRequest",
    "PersonasMatchCriteriaUpdateResponse",
    "PersonasPersona",
    "PersonasPersonaFactor",
    "PersonasPersonaInsight",
    "PersonasPersonaPersonalityTrait",
    "PersonasPersonalityTraitCreateRequest",
    "PersonasPersonalityTraitCreateResponse",
    "PersonasPersonalityTraitInDb",
    "PersonasPersonalityTraitReq",
    "PersonasSeed",
    "PersonasSeedGetManyResponse",
    "PersonasSeedUpsertRequest",
    "PersonasSeedsDeleteResponse",
    "PersonasSupplementalPromptCreateRequest",
    "PersonasSupplementalPromptDeleteResponse",
    "PersonasSupplementalPromptGetManyResponse",
    "PersonasSupplementalPromptResponse",
    "PersonasSupplementalPromptStatusUpdateRequest",
    "PersonasUpdateDemographicsRequest",
    "PersonasUpdateDemographicsResponse",
    "PgtypeBool",
    "PgtypeInfinityModifier",
    "PgtypeInt4",
    "PgtypeInt8",
    "PgtypeText",
    "PgtypeTimestamp",
    "PgtypeTimestamptz",
    "PixelClientInfo",
    "PixelClientPixelDetailsRequest",
    "PixelClientPixelDetailsResponse",
    "PixelClientPixelSummary",
    "PixelClientPixelTotals",
    "PixelDailyClientPixelMetrics",
    "PixelDailyPixelMetrics",
    "PixelDateRange",
    "PixelEnrichmentCoverage",
    "PixelPixelOverviewRequest",
    "PixelPixelOverviewResponse",
    "PixelPixelOverviewTotals",
    "ReportingActivityMetrics",
    "ReportingAffinityMeta",
    "ReportingAgeBreakdownRow",
    "ReportingAgeBucket",
    "ReportingAgeDistributionData",
    "ReportingBuyerScenario",
    "ReportingBuyerScenariosMeta",
    "ReportingCategoryPerformanceData",
    "ReportingCategoryPerformanceRow",
    "ReportingCategorySpendData",
    "ReportingCategorySpendWeek",
    "ReportingCategorySummary",
    "ReportingClientActivityEvent",
    "ReportingClientActivityQuery",
    "ReportingClientActivitySummary",
    "ReportingClientBreakdown",
    "ReportingClientEnrichmentCoverage",
    "ReportingCombinedActivityResponse",
    "ReportingComputedMetrics",
    "ReportingCustomerCycleMetrics",
    "ReportingCustomerInsightsRequest",
    "ReportingCustomerInsightsResponse",
    "ReportingCycleSummary",
    "ReportingCycleTiers",
    "ReportingDailyMetric",
    "ReportingDailyMetricsResponse",
    "ReportingDailyPredictions",
    "ReportingDailySummary",
    "ReportingDailyTotal",
    "ReportingDataAvailabilityQuery",
    "ReportingDataAvailabilityResponse",
    "ReportingDateRange",
    "ReportingDemographicsMeta",
    "ReportingEnrichmentCoverageQuery",
    "ReportingEnrichmentCoverageResponse",
    "ReportingEnrichmentCoverageSummary",
    "ReportingGenderSplitData",
    "ReportingGeographicDistributionData",
    "ReportingIncomeBand",
    "ReportingIncomeBandsData",
    "ReportingIntentBandData",
    "ReportingMetroArea",
    "ReportingModelInsightsRequest",
    "ReportingModelInsightsResponse",
    "ReportingModelJobDetail",
    "ReportingModelJobDetailResponse",
    "ReportingModelJobStats",
    "ReportingModelJobSummary",
    "ReportingModelJobsOverTime",
    "ReportingModelPrediction",
    "ReportingModelVersionStats",
    "ReportingOrgBreakdown",
    "ReportingOtherMarkets",
    "ReportingPeriodComparison",
    "ReportingPersonaBuyerScenariosRequest",
    "ReportingPersonaBuyerScenariosResponse",
    "ReportingPersonaDemographicsRequest",
    "ReportingPersonaDemographicsResponse",
    "ReportingPersonaProductAffinityRequest",
    "ReportingPersonaProductAffinityResponse",
    "ReportingPortfolioActivityQuery",
    "ReportingPortfolioActivityResponse",
    "ReportingPortfolioMetrics",
    "ReportingPredictionDetail",
    "ReportingPredictionDetailResponse",
    "ReportingPriceBucket",
    "ReportingPriceToleranceData",
    "ReportingProductAffinityQueryRequest",
    "ReportingProductAffinityResponse",
    "ReportingProductAffinityRow",
    "ReportingProductPerformanceData",
    "ReportingProductPerformanceRow",
    "ReportingPurchaseCycleData",
    "ReportingPurchaseTimingData",
    "ReportingPurchasesResponse",
    "ReportingQuery",
    "ReportingSessionsResponse",
    "ReportingSummaryKPIs",
    "ReportingTimingBucket",
    "ReportingTrafficPipelineDay",
    "ReportingTrafficTrendDay",
    "ReportsDataSourceConfig",
    "ReportsDateRange",
    "ReportsFacetItem",
    "ReportsLinkedKPI",
    "ReportsLinkedQuery",
    "ReportsMarkdownContentResponse",
    "ReportsMarkdownContentUpdateRequest",
    "ReportsOGImageRegenerateResponse",
    "ReportsPublicBranding",
    "ReportsPublicReportResponse",
    "ReportsRecommendation",
    "ReportsReportAgentStatusResponse",
    "ReportsReportArtifactCreateRequest",
    "ReportsReportArtifactDeleteResponse",
    "ReportsReportArtifactListResponse",
    "ReportsReportArtifactResponse",
    "ReportsReportArtifactSearchResponse",
    "ReportsReportArtifactUpdateRequest",
    "ReportsReportFacetsResponse",
    "ReportsReportGenerateRequest",
    "ReportsReportGenerateResponse",
    "ReportsShareLinkResponse",
    "ReportsSyncAgentRequest",
    "ReportsSyncAgentResponse",
    "SignalClientInfo",
    "SignalClientSignalDetailsRequest",
    "SignalClientSignalDetailsResponse",
    "SignalClientSignalSummary",
    "SignalClientSignalTotals",
    "SignalConversionSummary",
    "SignalConversionTotals",
    "SignalDailyConversionMetrics",
    "SignalDailyIntentBand",
    "SignalDailyIntentMetrics",
    "SignalDailyPurchaseMetrics",
    "SignalDateRange",
    "SignalIntentDistribution",
    "SignalIntentSummary",
    "SignalPersonaConversion",
    "SignalSignalOverviewRequest",
    "SignalSignalOverviewResponse",
    "SignalSignalOverviewTotals",
    "UtilsColorPairResult",
    "UtilsValidationError",
    "UtilsValidationErrors",
    "WorkbenchWorkbenchUrlCheckRequest",
    "WorkbenchWorkbenchUrlCheckResponse",
    "WorkbenchWorkbenchVersion",
    "WorkbenchWorkbenchVersionManyResponse",
    "WorkbenchWorkbenchVersionResponse",
    "WorkbenchWorkbenchVersionUpsertRequest",
]

# import apis into sdk package
from neurograph.v1.api.admin_api import AdminApi as AdminApi
from neurograph.v1.api.authentication_api import AuthenticationApi as AuthenticationApi
from neurograph.v1.api.client_api import ClientApi as ClientApi
from neurograph.v1.api.client_metadata_api import ClientMetadataApi as ClientMetadataApi
from neurograph.v1.api.dagster_api import DagsterApi as DagsterApi
from neurograph.v1.api.knowledge_api import KnowledgeApi as KnowledgeApi
from neurograph.v1.api.knowledge_extract_api import KnowledgeExtractApi as KnowledgeExtractApi
from neurograph.v1.api.lookup_api import LookupApi as LookupApi
from neurograph.v1.api.organization_api import OrganizationApi as OrganizationApi
from neurograph.v1.api.organization_metadata_api import OrganizationMetadataApi as OrganizationMetadataApi
from neurograph.v1.api.persona_api import PersonaApi as PersonaApi
from neurograph.v1.api.pixel_api import PixelApi as PixelApi
from neurograph.v1.api.reporting_api import ReportingApi as ReportingApi
from neurograph.v1.api.reports_api import ReportsApi as ReportsApi
from neurograph.v1.api.signal_api import SignalApi as SignalApi
from neurograph.v1.api.user_api import UserApi as UserApi
from neurograph.v1.api.workbench_api import WorkbenchApi as WorkbenchApi

# import ApiClient
from neurograph.v1.api_response import ApiResponse as ApiResponse
from neurograph.v1.api_client import ApiClient as ApiClient
from neurograph.v1.configuration import Configuration as Configuration
from neurograph.v1.exceptions import OpenApiException as OpenApiException
from neurograph.v1.exceptions import ApiTypeError as ApiTypeError
from neurograph.v1.exceptions import ApiValueError as ApiValueError
from neurograph.v1.exceptions import ApiKeyError as ApiKeyError
from neurograph.v1.exceptions import ApiAttributeError as ApiAttributeError
from neurograph.v1.exceptions import ApiException as ApiException

# import models into sdk package
from neurograph.v1.models.admin_permission_response import AdminPermissionResponse as AdminPermissionResponse
from neurograph.v1.models.admin_reset_password_request import AdminResetPasswordRequest as AdminResetPasswordRequest
from neurograph.v1.models.admin_reset_password_response import AdminResetPasswordResponse as AdminResetPasswordResponse
from neurograph.v1.models.admin_set_permission_request import AdminSetPermissionRequest as AdminSetPermissionRequest
from neurograph.v1.models.admin_upsert_user_request import AdminUpsertUserRequest as AdminUpsertUserRequest
from neurograph.v1.models.admin_upsert_user_response import AdminUpsertUserResponse as AdminUpsertUserResponse
from neurograph.v1.models.admin_user import AdminUser as AdminUser
from neurograph.v1.models.admin_user_detail_response import AdminUserDetailResponse as AdminUserDetailResponse
from neurograph.v1.models.admin_users_get_many_response import AdminUsersGetManyResponse as AdminUsersGetManyResponse
from neurograph.v1.models.admin_users_org_response import AdminUsersOrgResponse as AdminUsersOrgResponse
from neurograph.v1.models.auth_service_token_request import AuthServiceTokenRequest as AuthServiceTokenRequest
from neurograph.v1.models.auth_service_token_response import AuthServiceTokenResponse as AuthServiceTokenResponse
from neurograph.v1.models.auth_test_service_token_request import AuthTestServiceTokenRequest as AuthTestServiceTokenRequest
from neurograph.v1.models.auth_test_service_token_response import AuthTestServiceTokenResponse as AuthTestServiceTokenResponse
from neurograph.v1.models.auth_test_token_response import AuthTestTokenResponse as AuthTestTokenResponse
from neurograph.v1.models.client_client import ClientClient as ClientClient
from neurograph.v1.models.client_delete_metadata_request import ClientDeleteMetadataRequest as ClientDeleteMetadataRequest
from neurograph.v1.models.client_get_detail_response import ClientGetDetailResponse as ClientGetDetailResponse
from neurograph.v1.models.client_get_many_response import ClientGetManyResponse as ClientGetManyResponse
from neurograph.v1.models.client_healthcheck_create_request import ClientHealthcheckCreateRequest as ClientHealthcheckCreateRequest
from neurograph.v1.models.client_healthcheck_response import ClientHealthcheckResponse as ClientHealthcheckResponse
from neurograph.v1.models.client_healthcheck_rollup_response import ClientHealthcheckRollupResponse as ClientHealthcheckRollupResponse
from neurograph.v1.models.client_info import ClientInfo as ClientInfo
from neurograph.v1.models.client_kpi import ClientKpi as ClientKpi
from neurograph.v1.models.client_match_criteria_row_in_db import ClientMatchCriteriaRowInDb as ClientMatchCriteriaRowInDb
from neurograph.v1.models.client_metadata import ClientMetadata as ClientMetadata
from neurograph.v1.models.client_metadata_request import ClientMetadataRequest as ClientMetadataRequest
from neurograph.v1.models.client_metadata_response import ClientMetadataResponse as ClientMetadataResponse
from neurograph.v1.models.client_organization_brand import ClientOrganizationBrand as ClientOrganizationBrand
from neurograph.v1.models.client_organization_detail import ClientOrganizationDetail as ClientOrganizationDetail
from neurograph.v1.models.client_persona import ClientPersona as ClientPersona
from neurograph.v1.models.client_persona_assignment_stats import ClientPersonaAssignmentStats as ClientPersonaAssignmentStats
from neurograph.v1.models.client_persona_assignment_stats_response import ClientPersonaAssignmentStatsResponse as ClientPersonaAssignmentStatsResponse
from neurograph.v1.models.client_persona_factor import ClientPersonaFactor as ClientPersonaFactor
from neurograph.v1.models.client_persona_insight import ClientPersonaInsight as ClientPersonaInsight
from neurograph.v1.models.client_persona_personality_trait import ClientPersonaPersonalityTrait as ClientPersonaPersonalityTrait
from neurograph.v1.models.client_personas_response import ClientPersonasResponse as ClientPersonasResponse
from neurograph.v1.models.client_probe import ClientProbe as ClientProbe
from neurograph.v1.models.client_probe_todo_row import ClientProbeTodoRow as ClientProbeTodoRow
from neurograph.v1.models.client_query import ClientQuery as ClientQuery
from neurograph.v1.models.client_slack_message_request import ClientSlackMessageRequest as ClientSlackMessageRequest
from neurograph.v1.models.client_slack_message_response import ClientSlackMessageResponse as ClientSlackMessageResponse
from neurograph.v1.models.client_supplemental_prompt import ClientSupplementalPrompt as ClientSupplementalPrompt
from neurograph.v1.models.client_trigger_probe_response import ClientTriggerProbeResponse as ClientTriggerProbeResponse
from neurograph.v1.models.client_url_snapshot_response import ClientURLSnapshotResponse as ClientURLSnapshotResponse
from neurograph.v1.models.client_upsert_request import ClientUpsertRequest as ClientUpsertRequest
from neurograph.v1.models.client_upsert_response import ClientUpsertResponse as ClientUpsertResponse
from neurograph.v1.models.client_url_row import ClientUrlRow as ClientUrlRow
from neurograph.v1.models.client_url_snapshot_row import ClientUrlSnapshotRow as ClientUrlSnapshotRow
from neurograph.v1.models.client_url_upsert_request import ClientUrlUpsertRequest as ClientUrlUpsertRequest
from neurograph.v1.models.client_url_upsert_response import ClientUrlUpsertResponse as ClientUrlUpsertResponse
from neurograph.v1.models.client_urls_response import ClientUrlsResponse as ClientUrlsResponse
from neurograph.v1.models.client_workbench_config import ClientWorkbenchConfig as ClientWorkbenchConfig
from neurograph.v1.models.dagster_info import DagsterInfo as DagsterInfo
from neurograph.v1.models.dagster_log_create_request import DagsterLogCreateRequest as DagsterLogCreateRequest
from neurograph.v1.models.dagster_log_create_response import DagsterLogCreateResponse as DagsterLogCreateResponse
from neurograph.v1.models.dagster_log_get_response import DagsterLogGetResponse as DagsterLogGetResponse
from neurograph.v1.models.db_account_organization_brand import DbAccountOrganizationBrand as DbAccountOrganizationBrand
from neurograph.v1.models.db_client_url import DbClientUrl as DbClientUrl
from neurograph.v1.models.db_knowledge_customer import DbKnowledgeCustomer as DbKnowledgeCustomer
from neurograph.v1.models.db_knowledge_order import DbKnowledgeOrder as DbKnowledgeOrder
from neurograph.v1.models.db_knowledge_product import DbKnowledgeProduct as DbKnowledgeProduct
from neurograph.v1.models.db_knowledge_store import DbKnowledgeStore as DbKnowledgeStore
from neurograph.v1.models.db_my_client import DbMyClient as DbMyClient
from neurograph.v1.models.db_my_org import DbMyOrg as DbMyOrg
from neurograph.v1.models.db_persona_factor import DbPersonaFactor as DbPersonaFactor
from neurograph.v1.models.db_persona_factor_create_params import DbPersonaFactorCreateParams as DbPersonaFactorCreateParams
from neurograph.v1.models.db_persona_match_criterium import DbPersonaMatchCriterium as DbPersonaMatchCriterium
from neurograph.v1.models.db_pixel_snippet import DbPixelSnippet as DbPixelSnippet
from neurograph.v1.models.db_user_client_role import DbUserClientRole as DbUserClientRole
from neurograph.v1.models.db_user_in_db import DbUserInDb as DbUserInDb
from neurograph.v1.models.db_user_org_role import DbUserOrgRole as DbUserOrgRole
from neurograph.v1.models.db_user_role import DbUserRole as DbUserRole
from neurograph.v1.models.knowledge_assertion import KnowledgeAssertion as KnowledgeAssertion
from neurograph.v1.models.knowledge_assertion_create_request import KnowledgeAssertionCreateRequest as KnowledgeAssertionCreateRequest
from neurograph.v1.models.knowledge_assertion_list_response import KnowledgeAssertionListResponse as KnowledgeAssertionListResponse
from neurograph.v1.models.knowledge_assertion_query import KnowledgeAssertionQuery as KnowledgeAssertionQuery
from neurograph.v1.models.knowledge_assertion_response import KnowledgeAssertionResponse as KnowledgeAssertionResponse
from neurograph.v1.models.knowledge_customer_query import KnowledgeCustomerQuery as KnowledgeCustomerQuery
from neurograph.v1.models.knowledge_customer_response import KnowledgeCustomerResponse as KnowledgeCustomerResponse
from neurograph.v1.models.knowledge_enrichment_artifact import KnowledgeEnrichmentArtifact as KnowledgeEnrichmentArtifact
from neurograph.v1.models.knowledge_enrichment_artifact_create_request import KnowledgeEnrichmentArtifactCreateRequest as KnowledgeEnrichmentArtifactCreateRequest
from neurograph.v1.models.knowledge_enrichment_artifact_list_response import KnowledgeEnrichmentArtifactListResponse as KnowledgeEnrichmentArtifactListResponse
from neurograph.v1.models.knowledge_enrichment_artifact_response import KnowledgeEnrichmentArtifactResponse as KnowledgeEnrichmentArtifactResponse
from neurograph.v1.models.knowledge_enrichment_artifact_update_output_request import KnowledgeEnrichmentArtifactUpdateOutputRequest as KnowledgeEnrichmentArtifactUpdateOutputRequest
from neurograph.v1.models.knowledge_enrichment_artifact_update_status_request import KnowledgeEnrichmentArtifactUpdateStatusRequest as KnowledgeEnrichmentArtifactUpdateStatusRequest
from neurograph.v1.models.knowledge_enrichment_query import KnowledgeEnrichmentQuery as KnowledgeEnrichmentQuery
from neurograph.v1.models.knowledge_entity import KnowledgeEntity as KnowledgeEntity
from neurograph.v1.models.knowledge_entity_create_request import KnowledgeEntityCreateRequest as KnowledgeEntityCreateRequest
from neurograph.v1.models.knowledge_entity_create_response import KnowledgeEntityCreateResponse as KnowledgeEntityCreateResponse
from neurograph.v1.models.knowledge_entity_err_row import KnowledgeEntityErrRow as KnowledgeEntityErrRow
from neurograph.v1.models.knowledge_entity_extra import KnowledgeEntityExtra as KnowledgeEntityExtra
from neurograph.v1.models.knowledge_entity_get_many_response import KnowledgeEntityGetManyResponse as KnowledgeEntityGetManyResponse
from neurograph.v1.models.knowledge_entity_in_db import KnowledgeEntityInDb as KnowledgeEntityInDb
from neurograph.v1.models.knowledge_entity_relations import KnowledgeEntityRelations as KnowledgeEntityRelations
from neurograph.v1.models.knowledge_entity_schema import KnowledgeEntitySchema as KnowledgeEntitySchema
from neurograph.v1.models.knowledge_entity_schema_row import KnowledgeEntitySchemaRow as KnowledgeEntitySchemaRow
from neurograph.v1.models.knowledge_entity_schema_upsert_request import KnowledgeEntitySchemaUpsertRequest as KnowledgeEntitySchemaUpsertRequest
from neurograph.v1.models.knowledge_entity_schemas_response import KnowledgeEntitySchemasResponse as KnowledgeEntitySchemasResponse
from neurograph.v1.models.knowledge_entity_schemas_upsert_response import KnowledgeEntitySchemasUpsertResponse as KnowledgeEntitySchemasUpsertResponse
from neurograph.v1.models.knowledge_entity_type_response import KnowledgeEntityTypeResponse as KnowledgeEntityTypeResponse
from neurograph.v1.models.knowledge_entity_type_row import KnowledgeEntityTypeRow as KnowledgeEntityTypeRow
from neurograph.v1.models.knowledge_entity_type_upsert_request import KnowledgeEntityTypeUpsertRequest as KnowledgeEntityTypeUpsertRequest
from neurograph.v1.models.knowledge_entity_type_upsert_row import KnowledgeEntityTypeUpsertRow as KnowledgeEntityTypeUpsertRow
from neurograph.v1.models.knowledge_entity_upsert_request import KnowledgeEntityUpsertRequest as KnowledgeEntityUpsertRequest
from neurograph.v1.models.knowledge_entity_upsert_response import KnowledgeEntityUpsertResponse as KnowledgeEntityUpsertResponse
from neurograph.v1.models.knowledge_ingest_raw_request import KnowledgeIngestRawRequest as KnowledgeIngestRawRequest
from neurograph.v1.models.knowledge_ingest_raw_response import KnowledgeIngestRawResponse as KnowledgeIngestRawResponse
from neurograph.v1.models.knowledge_ingest_raw_row import KnowledgeIngestRawRow as KnowledgeIngestRawRow
from neurograph.v1.models.knowledge_kind_response import KnowledgeKindResponse as KnowledgeKindResponse
from neurograph.v1.models.knowledge_order_query import KnowledgeOrderQuery as KnowledgeOrderQuery
from neurograph.v1.models.knowledge_order_response import KnowledgeOrderResponse as KnowledgeOrderResponse
from neurograph.v1.models.knowledge_product import KnowledgeProduct as KnowledgeProduct
from neurograph.v1.models.knowledge_product_query import KnowledgeProductQuery as KnowledgeProductQuery
from neurograph.v1.models.knowledge_product_response import KnowledgeProductResponse as KnowledgeProductResponse
from neurograph.v1.models.knowledge_product_upsert_request import KnowledgeProductUpsertRequest as KnowledgeProductUpsertRequest
from neurograph.v1.models.knowledge_product_upsert_response import KnowledgeProductUpsertResponse as KnowledgeProductUpsertResponse
from neurograph.v1.models.knowledge_query import KnowledgeQuery as KnowledgeQuery
from neurograph.v1.models.knowledge_store_query import KnowledgeStoreQuery as KnowledgeStoreQuery
from neurograph.v1.models.knowledge_store_response import KnowledgeStoreResponse as KnowledgeStoreResponse
from neurograph.v1.models.lookup_env import LookupEnv as LookupEnv
from neurograph.v1.models.lookup_language import LookupLanguage as LookupLanguage
from neurograph.v1.models.lookup_language_response import LookupLanguageResponse as LookupLanguageResponse
from neurograph.v1.models.lookup_lookup_environments_response import LookupLookupEnvironmentsResponse as LookupLookupEnvironmentsResponse
from neurograph.v1.models.lookup_role import LookupRole as LookupRole
from neurograph.v1.models.lookup_roles_response import LookupRolesResponse as LookupRolesResponse
from neurograph.v1.models.lookup_state import LookupState as LookupState
from neurograph.v1.models.lookup_state_response import LookupStateResponse as LookupStateResponse
from neurograph.v1.models.lookup_states_response import LookupStatesResponse as LookupStatesResponse
from neurograph.v1.models.lookup_sync_snippets_response import LookupSyncSnippetsResponse as LookupSyncSnippetsResponse
from neurograph.v1.models.lookup_uid import LookupUid as LookupUid
from neurograph.v1.models.lookup_uids_response import LookupUidsResponse as LookupUidsResponse
from neurograph.v1.models.me_my_profile_response import MeMyProfileResponse as MeMyProfileResponse
from neurograph.v1.models.openai_accessibility_info import OpenaiAccessibilityInfo as OpenaiAccessibilityInfo
from neurograph.v1.models.openai_brand_analysis import OpenaiBrandAnalysis as OpenaiBrandAnalysis
from neurograph.v1.models.openai_brand_colors import OpenaiBrandColors as OpenaiBrandColors
from neurograph.v1.models.openai_generated_brand import OpenaiGeneratedBrand as OpenaiGeneratedBrand
from neurograph.v1.models.organizations_apply_preset_request import OrganizationsApplyPresetRequest as OrganizationsApplyPresetRequest
from neurograph.v1.models.organizations_apply_preset_response import OrganizationsApplyPresetResponse as OrganizationsApplyPresetResponse
from neurograph.v1.models.organizations_brand import OrganizationsBrand as OrganizationsBrand
from neurograph.v1.models.organizations_brand_detail_response import OrganizationsBrandDetailResponse as OrganizationsBrandDetailResponse
from neurograph.v1.models.organizations_brand_generation_request import OrganizationsBrandGenerationRequest as OrganizationsBrandGenerationRequest
from neurograph.v1.models.organizations_brand_generation_response import OrganizationsBrandGenerationResponse as OrganizationsBrandGenerationResponse
from neurograph.v1.models.organizations_brand_history_detail_response import OrganizationsBrandHistoryDetailResponse as OrganizationsBrandHistoryDetailResponse
from neurograph.v1.models.organizations_brand_history_item import OrganizationsBrandHistoryItem as OrganizationsBrandHistoryItem
from neurograph.v1.models.organizations_brand_history_list_response import OrganizationsBrandHistoryListResponse as OrganizationsBrandHistoryListResponse
from neurograph.v1.models.organizations_brand_rollback_request import OrganizationsBrandRollbackRequest as OrganizationsBrandRollbackRequest
from neurograph.v1.models.organizations_brand_rollback_response import OrganizationsBrandRollbackResponse as OrganizationsBrandRollbackResponse
from neurograph.v1.models.organizations_brand_upsert_request import OrganizationsBrandUpsertRequest as OrganizationsBrandUpsertRequest
from neurograph.v1.models.organizations_component_config import OrganizationsComponentConfig as OrganizationsComponentConfig
from neurograph.v1.models.organizations_create_request import OrganizationsCreateRequest as OrganizationsCreateRequest
from neurograph.v1.models.organizations_delete_metadata_request import OrganizationsDeleteMetadataRequest as OrganizationsDeleteMetadataRequest
from neurograph.v1.models.organizations_delete_metadata_response import OrganizationsDeleteMetadataResponse as OrganizationsDeleteMetadataResponse
from neurograph.v1.models.organizations_detail_response import OrganizationsDetailResponse as OrganizationsDetailResponse
from neurograph.v1.models.organizations_gamma_block_settings import OrganizationsGammaBlockSettings as OrganizationsGammaBlockSettings
from neurograph.v1.models.organizations_gamma_button_settings import OrganizationsGammaButtonSettings as OrganizationsGammaButtonSettings
from neurograph.v1.models.organizations_gamma_card_settings import OrganizationsGammaCardSettings as OrganizationsGammaCardSettings
from neurograph.v1.models.organizations_gamma_color_settings import OrganizationsGammaColorSettings as OrganizationsGammaColorSettings
from neurograph.v1.models.organizations_gamma_design_settings import OrganizationsGammaDesignSettings as OrganizationsGammaDesignSettings
from neurograph.v1.models.organizations_gamma_font_settings import OrganizationsGammaFontSettings as OrganizationsGammaFontSettings
from neurograph.v1.models.organizations_gamma_theme_request import OrganizationsGammaThemeRequest as OrganizationsGammaThemeRequest
from neurograph.v1.models.organizations_gamma_theme_response import OrganizationsGammaThemeResponse as OrganizationsGammaThemeResponse
from neurograph.v1.models.organizations_gamma_theme_settings import OrganizationsGammaThemeSettings as OrganizationsGammaThemeSettings
from neurograph.v1.models.organizations_generate_tokens_request import OrganizationsGenerateTokensRequest as OrganizationsGenerateTokensRequest
from neurograph.v1.models.organizations_generate_tokens_response import OrganizationsGenerateTokensResponse as OrganizationsGenerateTokensResponse
from neurograph.v1.models.organizations_generation_metadata import OrganizationsGenerationMetadata as OrganizationsGenerationMetadata
from neurograph.v1.models.organizations_get_branding_tokens_response import OrganizationsGetBrandingTokensResponse as OrganizationsGetBrandingTokensResponse
from neurograph.v1.models.organizations_get_many_response import OrganizationsGetManyResponse as OrganizationsGetManyResponse
from neurograph.v1.models.organizations_metadata import OrganizationsMetadata as OrganizationsMetadata
from neurograph.v1.models.organizations_metadata_request import OrganizationsMetadataRequest as OrganizationsMetadataRequest
from neurograph.v1.models.organizations_metadata_response import OrganizationsMetadataResponse as OrganizationsMetadataResponse
from neurograph.v1.models.organizations_organization import OrganizationsOrganization as OrganizationsOrganization
from neurograph.v1.models.organizations_organization_set_workbench_request import OrganizationsOrganizationSetWorkbenchRequest as OrganizationsOrganizationSetWorkbenchRequest
from neurograph.v1.models.organizations_organization_set_workbench_response import OrganizationsOrganizationSetWorkbenchResponse as OrganizationsOrganizationSetWorkbenchResponse
from neurograph.v1.models.organizations_organization_update_request import OrganizationsOrganizationUpdateRequest as OrganizationsOrganizationUpdateRequest
from neurograph.v1.models.organizations_preset_recommendation import OrganizationsPresetRecommendation as OrganizationsPresetRecommendation
from neurograph.v1.models.organizations_preview_branding_request import OrganizationsPreviewBrandingRequest as OrganizationsPreviewBrandingRequest
from neurograph.v1.models.organizations_preview_branding_response import OrganizationsPreviewBrandingResponse as OrganizationsPreviewBrandingResponse
from neurograph.v1.models.organizations_recommend_presets_response import OrganizationsRecommendPresetsResponse as OrganizationsRecommendPresetsResponse
from neurograph.v1.models.organizations_screenshot_url_request import OrganizationsScreenshotURLRequest as OrganizationsScreenshotURLRequest
from neurograph.v1.models.organizations_screenshot_url_response import OrganizationsScreenshotURLResponse as OrganizationsScreenshotURLResponse
from neurograph.v1.models.organizations_spacing_config import OrganizationsSpacingConfig as OrganizationsSpacingConfig
from neurograph.v1.models.organizations_test_accessibility_request import OrganizationsTestAccessibilityRequest as OrganizationsTestAccessibilityRequest
from neurograph.v1.models.organizations_test_accessibility_response import OrganizationsTestAccessibilityResponse as OrganizationsTestAccessibilityResponse
from neurograph.v1.models.organizations_theme_preset_create_request import OrganizationsThemePresetCreateRequest as OrganizationsThemePresetCreateRequest
from neurograph.v1.models.organizations_theme_preset_list_response import OrganizationsThemePresetListResponse as OrganizationsThemePresetListResponse
from neurograph.v1.models.organizations_theme_preset_response import OrganizationsThemePresetResponse as OrganizationsThemePresetResponse
from neurograph.v1.models.organizations_theme_preset_update_request import OrganizationsThemePresetUpdateRequest as OrganizationsThemePresetUpdateRequest
from neurograph.v1.models.organizations_typography_config import OrganizationsTypographyConfig as OrganizationsTypographyConfig
from neurograph.v1.models.organizations_validate_branding_request import OrganizationsValidateBrandingRequest as OrganizationsValidateBrandingRequest
from neurograph.v1.models.organizations_validate_branding_response import OrganizationsValidateBrandingResponse as OrganizationsValidateBrandingResponse
from neurograph.v1.models.organizations_workbench_config import OrganizationsWorkbenchConfig as OrganizationsWorkbenchConfig
from neurograph.v1.models.personas_factor_create_request import PersonasFactorCreateRequest as PersonasFactorCreateRequest
from neurograph.v1.models.personas_factor_create_response import PersonasFactorCreateResponse as PersonasFactorCreateResponse
from neurograph.v1.models.personas_factor_delete_response import PersonasFactorDeleteResponse as PersonasFactorDeleteResponse
from neurograph.v1.models.personas_factor_row import PersonasFactorRow as PersonasFactorRow
from neurograph.v1.models.personas_factor_update_request import PersonasFactorUpdateRequest as PersonasFactorUpdateRequest
from neurograph.v1.models.personas_factor_update_response import PersonasFactorUpdateResponse as PersonasFactorUpdateResponse
from neurograph.v1.models.personas_get_latest_persona_instance_request import PersonasGetLatestPersonaInstanceRequest as PersonasGetLatestPersonaInstanceRequest
from neurograph.v1.models.personas_get_persona_instance_response import PersonasGetPersonaInstanceResponse as PersonasGetPersonaInstanceResponse
from neurograph.v1.models.personas_insight_create_request import PersonasInsightCreateRequest as PersonasInsightCreateRequest
from neurograph.v1.models.personas_insight_create_response import PersonasInsightCreateResponse as PersonasInsightCreateResponse
from neurograph.v1.models.personas_instance_create_request import PersonasInstanceCreateRequest as PersonasInstanceCreateRequest
from neurograph.v1.models.personas_instance_create_response import PersonasInstanceCreateResponse as PersonasInstanceCreateResponse
from neurograph.v1.models.personas_instance_delete_many_request import PersonasInstanceDeleteManyRequest as PersonasInstanceDeleteManyRequest
from neurograph.v1.models.personas_instance_delete_many_response import PersonasInstanceDeleteManyResponse as PersonasInstanceDeleteManyResponse
from neurograph.v1.models.personas_instances_response import PersonasInstancesResponse as PersonasInstancesResponse
from neurograph.v1.models.personas_kpi import PersonasKpi as PersonasKpi
from neurograph.v1.models.personas_kpi_create_request import PersonasKpiCreateRequest as PersonasKpiCreateRequest
from neurograph.v1.models.personas_kpi_create_response import PersonasKpiCreateResponse as PersonasKpiCreateResponse
from neurograph.v1.models.personas_kpi_req_row import PersonasKpiReqRow as PersonasKpiReqRow
from neurograph.v1.models.personas_kpi_row_in_db import PersonasKpiRowInDb as PersonasKpiRowInDb
from neurograph.v1.models.personas_match_criteria_delete_response import PersonasMatchCriteriaDeleteResponse as PersonasMatchCriteriaDeleteResponse
from neurograph.v1.models.personas_match_criteria_reorder_item import PersonasMatchCriteriaReorderItem as PersonasMatchCriteriaReorderItem
from neurograph.v1.models.personas_match_criteria_reorder_request import PersonasMatchCriteriaReorderRequest as PersonasMatchCriteriaReorderRequest
from neurograph.v1.models.personas_match_criteria_reorder_response import PersonasMatchCriteriaReorderResponse as PersonasMatchCriteriaReorderResponse
from neurograph.v1.models.personas_match_criteria_request import PersonasMatchCriteriaRequest as PersonasMatchCriteriaRequest
from neurograph.v1.models.personas_match_criteria_response import PersonasMatchCriteriaResponse as PersonasMatchCriteriaResponse
from neurograph.v1.models.personas_match_criteria_row_in import PersonasMatchCriteriaRowIn as PersonasMatchCriteriaRowIn
from neurograph.v1.models.personas_match_criteria_row_in_db import PersonasMatchCriteriaRowInDb as PersonasMatchCriteriaRowInDb
from neurograph.v1.models.personas_match_criteria_update_request import PersonasMatchCriteriaUpdateRequest as PersonasMatchCriteriaUpdateRequest
from neurograph.v1.models.personas_match_criteria_update_response import PersonasMatchCriteriaUpdateResponse as PersonasMatchCriteriaUpdateResponse
from neurograph.v1.models.personas_persona import PersonasPersona as PersonasPersona
from neurograph.v1.models.personas_persona_factor import PersonasPersonaFactor as PersonasPersonaFactor
from neurograph.v1.models.personas_persona_insight import PersonasPersonaInsight as PersonasPersonaInsight
from neurograph.v1.models.personas_persona_personality_trait import PersonasPersonaPersonalityTrait as PersonasPersonaPersonalityTrait
from neurograph.v1.models.personas_personality_trait_create_request import PersonasPersonalityTraitCreateRequest as PersonasPersonalityTraitCreateRequest
from neurograph.v1.models.personas_personality_trait_create_response import PersonasPersonalityTraitCreateResponse as PersonasPersonalityTraitCreateResponse
from neurograph.v1.models.personas_personality_trait_in_db import PersonasPersonalityTraitInDb as PersonasPersonalityTraitInDb
from neurograph.v1.models.personas_personality_trait_req import PersonasPersonalityTraitReq as PersonasPersonalityTraitReq
from neurograph.v1.models.personas_seed import PersonasSeed as PersonasSeed
from neurograph.v1.models.personas_seed_get_many_response import PersonasSeedGetManyResponse as PersonasSeedGetManyResponse
from neurograph.v1.models.personas_seed_upsert_request import PersonasSeedUpsertRequest as PersonasSeedUpsertRequest
from neurograph.v1.models.personas_seeds_delete_response import PersonasSeedsDeleteResponse as PersonasSeedsDeleteResponse
from neurograph.v1.models.personas_supplemental_prompt_create_request import PersonasSupplementalPromptCreateRequest as PersonasSupplementalPromptCreateRequest
from neurograph.v1.models.personas_supplemental_prompt_delete_response import PersonasSupplementalPromptDeleteResponse as PersonasSupplementalPromptDeleteResponse
from neurograph.v1.models.personas_supplemental_prompt_get_many_response import PersonasSupplementalPromptGetManyResponse as PersonasSupplementalPromptGetManyResponse
from neurograph.v1.models.personas_supplemental_prompt_response import PersonasSupplementalPromptResponse as PersonasSupplementalPromptResponse
from neurograph.v1.models.personas_supplemental_prompt_status_update_request import PersonasSupplementalPromptStatusUpdateRequest as PersonasSupplementalPromptStatusUpdateRequest
from neurograph.v1.models.personas_update_demographics_request import PersonasUpdateDemographicsRequest as PersonasUpdateDemographicsRequest
from neurograph.v1.models.personas_update_demographics_response import PersonasUpdateDemographicsResponse as PersonasUpdateDemographicsResponse
from neurograph.v1.models.pgtype_bool import PgtypeBool as PgtypeBool
from neurograph.v1.models.pgtype_infinity_modifier import PgtypeInfinityModifier as PgtypeInfinityModifier
from neurograph.v1.models.pgtype_int4 import PgtypeInt4 as PgtypeInt4
from neurograph.v1.models.pgtype_int8 import PgtypeInt8 as PgtypeInt8
from neurograph.v1.models.pgtype_text import PgtypeText as PgtypeText
from neurograph.v1.models.pgtype_timestamp import PgtypeTimestamp as PgtypeTimestamp
from neurograph.v1.models.pgtype_timestamptz import PgtypeTimestamptz as PgtypeTimestamptz
from neurograph.v1.models.pixel_client_info import PixelClientInfo as PixelClientInfo
from neurograph.v1.models.pixel_client_pixel_details_request import PixelClientPixelDetailsRequest as PixelClientPixelDetailsRequest
from neurograph.v1.models.pixel_client_pixel_details_response import PixelClientPixelDetailsResponse as PixelClientPixelDetailsResponse
from neurograph.v1.models.pixel_client_pixel_summary import PixelClientPixelSummary as PixelClientPixelSummary
from neurograph.v1.models.pixel_client_pixel_totals import PixelClientPixelTotals as PixelClientPixelTotals
from neurograph.v1.models.pixel_daily_client_pixel_metrics import PixelDailyClientPixelMetrics as PixelDailyClientPixelMetrics
from neurograph.v1.models.pixel_daily_pixel_metrics import PixelDailyPixelMetrics as PixelDailyPixelMetrics
from neurograph.v1.models.pixel_date_range import PixelDateRange as PixelDateRange
from neurograph.v1.models.pixel_enrichment_coverage import PixelEnrichmentCoverage as PixelEnrichmentCoverage
from neurograph.v1.models.pixel_pixel_overview_request import PixelPixelOverviewRequest as PixelPixelOverviewRequest
from neurograph.v1.models.pixel_pixel_overview_response import PixelPixelOverviewResponse as PixelPixelOverviewResponse
from neurograph.v1.models.pixel_pixel_overview_totals import PixelPixelOverviewTotals as PixelPixelOverviewTotals
from neurograph.v1.models.reporting_activity_metrics import ReportingActivityMetrics as ReportingActivityMetrics
from neurograph.v1.models.reporting_affinity_meta import ReportingAffinityMeta as ReportingAffinityMeta
from neurograph.v1.models.reporting_age_breakdown_row import ReportingAgeBreakdownRow as ReportingAgeBreakdownRow
from neurograph.v1.models.reporting_age_bucket import ReportingAgeBucket as ReportingAgeBucket
from neurograph.v1.models.reporting_age_distribution_data import ReportingAgeDistributionData as ReportingAgeDistributionData
from neurograph.v1.models.reporting_buyer_scenario import ReportingBuyerScenario as ReportingBuyerScenario
from neurograph.v1.models.reporting_buyer_scenarios_meta import ReportingBuyerScenariosMeta as ReportingBuyerScenariosMeta
from neurograph.v1.models.reporting_category_performance_data import ReportingCategoryPerformanceData as ReportingCategoryPerformanceData
from neurograph.v1.models.reporting_category_performance_row import ReportingCategoryPerformanceRow as ReportingCategoryPerformanceRow
from neurograph.v1.models.reporting_category_spend_data import ReportingCategorySpendData as ReportingCategorySpendData
from neurograph.v1.models.reporting_category_spend_week import ReportingCategorySpendWeek as ReportingCategorySpendWeek
from neurograph.v1.models.reporting_category_summary import ReportingCategorySummary as ReportingCategorySummary
from neurograph.v1.models.reporting_client_activity_event import ReportingClientActivityEvent as ReportingClientActivityEvent
from neurograph.v1.models.reporting_client_activity_query import ReportingClientActivityQuery as ReportingClientActivityQuery
from neurograph.v1.models.reporting_client_activity_summary import ReportingClientActivitySummary as ReportingClientActivitySummary
from neurograph.v1.models.reporting_client_breakdown import ReportingClientBreakdown as ReportingClientBreakdown
from neurograph.v1.models.reporting_client_enrichment_coverage import ReportingClientEnrichmentCoverage as ReportingClientEnrichmentCoverage
from neurograph.v1.models.reporting_combined_activity_response import ReportingCombinedActivityResponse as ReportingCombinedActivityResponse
from neurograph.v1.models.reporting_computed_metrics import ReportingComputedMetrics as ReportingComputedMetrics
from neurograph.v1.models.reporting_customer_cycle_metrics import ReportingCustomerCycleMetrics as ReportingCustomerCycleMetrics
from neurograph.v1.models.reporting_customer_insights_request import ReportingCustomerInsightsRequest as ReportingCustomerInsightsRequest
from neurograph.v1.models.reporting_customer_insights_response import ReportingCustomerInsightsResponse as ReportingCustomerInsightsResponse
from neurograph.v1.models.reporting_cycle_summary import ReportingCycleSummary as ReportingCycleSummary
from neurograph.v1.models.reporting_cycle_tiers import ReportingCycleTiers as ReportingCycleTiers
from neurograph.v1.models.reporting_daily_metric import ReportingDailyMetric as ReportingDailyMetric
from neurograph.v1.models.reporting_daily_metrics_response import ReportingDailyMetricsResponse as ReportingDailyMetricsResponse
from neurograph.v1.models.reporting_daily_predictions import ReportingDailyPredictions as ReportingDailyPredictions
from neurograph.v1.models.reporting_daily_summary import ReportingDailySummary as ReportingDailySummary
from neurograph.v1.models.reporting_daily_total import ReportingDailyTotal as ReportingDailyTotal
from neurograph.v1.models.reporting_data_availability_query import ReportingDataAvailabilityQuery as ReportingDataAvailabilityQuery
from neurograph.v1.models.reporting_data_availability_response import ReportingDataAvailabilityResponse as ReportingDataAvailabilityResponse
from neurograph.v1.models.reporting_date_range import ReportingDateRange as ReportingDateRange
from neurograph.v1.models.reporting_demographics_meta import ReportingDemographicsMeta as ReportingDemographicsMeta
from neurograph.v1.models.reporting_enrichment_coverage_query import ReportingEnrichmentCoverageQuery as ReportingEnrichmentCoverageQuery
from neurograph.v1.models.reporting_enrichment_coverage_response import ReportingEnrichmentCoverageResponse as ReportingEnrichmentCoverageResponse
from neurograph.v1.models.reporting_enrichment_coverage_summary import ReportingEnrichmentCoverageSummary as ReportingEnrichmentCoverageSummary
from neurograph.v1.models.reporting_gender_split_data import ReportingGenderSplitData as ReportingGenderSplitData
from neurograph.v1.models.reporting_geographic_distribution_data import ReportingGeographicDistributionData as ReportingGeographicDistributionData
from neurograph.v1.models.reporting_income_band import ReportingIncomeBand as ReportingIncomeBand
from neurograph.v1.models.reporting_income_bands_data import ReportingIncomeBandsData as ReportingIncomeBandsData
from neurograph.v1.models.reporting_intent_band_data import ReportingIntentBandData as ReportingIntentBandData
from neurograph.v1.models.reporting_metro_area import ReportingMetroArea as ReportingMetroArea
from neurograph.v1.models.reporting_model_insights_request import ReportingModelInsightsRequest as ReportingModelInsightsRequest
from neurograph.v1.models.reporting_model_insights_response import ReportingModelInsightsResponse as ReportingModelInsightsResponse
from neurograph.v1.models.reporting_model_job_detail import ReportingModelJobDetail as ReportingModelJobDetail
from neurograph.v1.models.reporting_model_job_detail_response import ReportingModelJobDetailResponse as ReportingModelJobDetailResponse
from neurograph.v1.models.reporting_model_job_stats import ReportingModelJobStats as ReportingModelJobStats
from neurograph.v1.models.reporting_model_job_summary import ReportingModelJobSummary as ReportingModelJobSummary
from neurograph.v1.models.reporting_model_jobs_over_time import ReportingModelJobsOverTime as ReportingModelJobsOverTime
from neurograph.v1.models.reporting_model_prediction import ReportingModelPrediction as ReportingModelPrediction
from neurograph.v1.models.reporting_model_version_stats import ReportingModelVersionStats as ReportingModelVersionStats
from neurograph.v1.models.reporting_org_breakdown import ReportingOrgBreakdown as ReportingOrgBreakdown
from neurograph.v1.models.reporting_other_markets import ReportingOtherMarkets as ReportingOtherMarkets
from neurograph.v1.models.reporting_period_comparison import ReportingPeriodComparison as ReportingPeriodComparison
from neurograph.v1.models.reporting_persona_buyer_scenarios_request import ReportingPersonaBuyerScenariosRequest as ReportingPersonaBuyerScenariosRequest
from neurograph.v1.models.reporting_persona_buyer_scenarios_response import ReportingPersonaBuyerScenariosResponse as ReportingPersonaBuyerScenariosResponse
from neurograph.v1.models.reporting_persona_demographics_request import ReportingPersonaDemographicsRequest as ReportingPersonaDemographicsRequest
from neurograph.v1.models.reporting_persona_demographics_response import ReportingPersonaDemographicsResponse as ReportingPersonaDemographicsResponse
from neurograph.v1.models.reporting_persona_product_affinity_request import ReportingPersonaProductAffinityRequest as ReportingPersonaProductAffinityRequest
from neurograph.v1.models.reporting_persona_product_affinity_response import ReportingPersonaProductAffinityResponse as ReportingPersonaProductAffinityResponse
from neurograph.v1.models.reporting_portfolio_activity_query import ReportingPortfolioActivityQuery as ReportingPortfolioActivityQuery
from neurograph.v1.models.reporting_portfolio_activity_response import ReportingPortfolioActivityResponse as ReportingPortfolioActivityResponse
from neurograph.v1.models.reporting_portfolio_metrics import ReportingPortfolioMetrics as ReportingPortfolioMetrics
from neurograph.v1.models.reporting_prediction_detail import ReportingPredictionDetail as ReportingPredictionDetail
from neurograph.v1.models.reporting_prediction_detail_response import ReportingPredictionDetailResponse as ReportingPredictionDetailResponse
from neurograph.v1.models.reporting_price_bucket import ReportingPriceBucket as ReportingPriceBucket
from neurograph.v1.models.reporting_price_tolerance_data import ReportingPriceToleranceData as ReportingPriceToleranceData
from neurograph.v1.models.reporting_product_affinity_query_request import ReportingProductAffinityQueryRequest as ReportingProductAffinityQueryRequest
from neurograph.v1.models.reporting_product_affinity_response import ReportingProductAffinityResponse as ReportingProductAffinityResponse
from neurograph.v1.models.reporting_product_affinity_row import ReportingProductAffinityRow as ReportingProductAffinityRow
from neurograph.v1.models.reporting_product_performance_data import ReportingProductPerformanceData as ReportingProductPerformanceData
from neurograph.v1.models.reporting_product_performance_row import ReportingProductPerformanceRow as ReportingProductPerformanceRow
from neurograph.v1.models.reporting_purchase_cycle_data import ReportingPurchaseCycleData as ReportingPurchaseCycleData
from neurograph.v1.models.reporting_purchase_timing_data import ReportingPurchaseTimingData as ReportingPurchaseTimingData
from neurograph.v1.models.reporting_purchases_response import ReportingPurchasesResponse as ReportingPurchasesResponse
from neurograph.v1.models.reporting_query import ReportingQuery as ReportingQuery
from neurograph.v1.models.reporting_sessions_response import ReportingSessionsResponse as ReportingSessionsResponse
from neurograph.v1.models.reporting_summary_kpis import ReportingSummaryKPIs as ReportingSummaryKPIs
from neurograph.v1.models.reporting_timing_bucket import ReportingTimingBucket as ReportingTimingBucket
from neurograph.v1.models.reporting_traffic_pipeline_day import ReportingTrafficPipelineDay as ReportingTrafficPipelineDay
from neurograph.v1.models.reporting_traffic_trend_day import ReportingTrafficTrendDay as ReportingTrafficTrendDay
from neurograph.v1.models.reports_data_source_config import ReportsDataSourceConfig as ReportsDataSourceConfig
from neurograph.v1.models.reports_date_range import ReportsDateRange as ReportsDateRange
from neurograph.v1.models.reports_facet_item import ReportsFacetItem as ReportsFacetItem
from neurograph.v1.models.reports_linked_kpi import ReportsLinkedKPI as ReportsLinkedKPI
from neurograph.v1.models.reports_linked_query import ReportsLinkedQuery as ReportsLinkedQuery
from neurograph.v1.models.reports_markdown_content_response import ReportsMarkdownContentResponse as ReportsMarkdownContentResponse
from neurograph.v1.models.reports_markdown_content_update_request import ReportsMarkdownContentUpdateRequest as ReportsMarkdownContentUpdateRequest
from neurograph.v1.models.reports_og_image_regenerate_response import ReportsOGImageRegenerateResponse as ReportsOGImageRegenerateResponse
from neurograph.v1.models.reports_public_branding import ReportsPublicBranding as ReportsPublicBranding
from neurograph.v1.models.reports_public_report_response import ReportsPublicReportResponse as ReportsPublicReportResponse
from neurograph.v1.models.reports_recommendation import ReportsRecommendation as ReportsRecommendation
from neurograph.v1.models.reports_report_agent_status_response import ReportsReportAgentStatusResponse as ReportsReportAgentStatusResponse
from neurograph.v1.models.reports_report_artifact_create_request import ReportsReportArtifactCreateRequest as ReportsReportArtifactCreateRequest
from neurograph.v1.models.reports_report_artifact_delete_response import ReportsReportArtifactDeleteResponse as ReportsReportArtifactDeleteResponse
from neurograph.v1.models.reports_report_artifact_list_response import ReportsReportArtifactListResponse as ReportsReportArtifactListResponse
from neurograph.v1.models.reports_report_artifact_response import ReportsReportArtifactResponse as ReportsReportArtifactResponse
from neurograph.v1.models.reports_report_artifact_search_response import ReportsReportArtifactSearchResponse as ReportsReportArtifactSearchResponse
from neurograph.v1.models.reports_report_artifact_update_request import ReportsReportArtifactUpdateRequest as ReportsReportArtifactUpdateRequest
from neurograph.v1.models.reports_report_facets_response import ReportsReportFacetsResponse as ReportsReportFacetsResponse
from neurograph.v1.models.reports_report_generate_request import ReportsReportGenerateRequest as ReportsReportGenerateRequest
from neurograph.v1.models.reports_report_generate_response import ReportsReportGenerateResponse as ReportsReportGenerateResponse
from neurograph.v1.models.reports_share_link_response import ReportsShareLinkResponse as ReportsShareLinkResponse
from neurograph.v1.models.reports_sync_agent_request import ReportsSyncAgentRequest as ReportsSyncAgentRequest
from neurograph.v1.models.reports_sync_agent_response import ReportsSyncAgentResponse as ReportsSyncAgentResponse
from neurograph.v1.models.signal_client_info import SignalClientInfo as SignalClientInfo
from neurograph.v1.models.signal_client_signal_details_request import SignalClientSignalDetailsRequest as SignalClientSignalDetailsRequest
from neurograph.v1.models.signal_client_signal_details_response import SignalClientSignalDetailsResponse as SignalClientSignalDetailsResponse
from neurograph.v1.models.signal_client_signal_summary import SignalClientSignalSummary as SignalClientSignalSummary
from neurograph.v1.models.signal_client_signal_totals import SignalClientSignalTotals as SignalClientSignalTotals
from neurograph.v1.models.signal_conversion_summary import SignalConversionSummary as SignalConversionSummary
from neurograph.v1.models.signal_conversion_totals import SignalConversionTotals as SignalConversionTotals
from neurograph.v1.models.signal_daily_conversion_metrics import SignalDailyConversionMetrics as SignalDailyConversionMetrics
from neurograph.v1.models.signal_daily_intent_band import SignalDailyIntentBand as SignalDailyIntentBand
from neurograph.v1.models.signal_daily_intent_metrics import SignalDailyIntentMetrics as SignalDailyIntentMetrics
from neurograph.v1.models.signal_daily_purchase_metrics import SignalDailyPurchaseMetrics as SignalDailyPurchaseMetrics
from neurograph.v1.models.signal_date_range import SignalDateRange as SignalDateRange
from neurograph.v1.models.signal_intent_distribution import SignalIntentDistribution as SignalIntentDistribution
from neurograph.v1.models.signal_intent_summary import SignalIntentSummary as SignalIntentSummary
from neurograph.v1.models.signal_persona_conversion import SignalPersonaConversion as SignalPersonaConversion
from neurograph.v1.models.signal_signal_overview_request import SignalSignalOverviewRequest as SignalSignalOverviewRequest
from neurograph.v1.models.signal_signal_overview_response import SignalSignalOverviewResponse as SignalSignalOverviewResponse
from neurograph.v1.models.signal_signal_overview_totals import SignalSignalOverviewTotals as SignalSignalOverviewTotals
from neurograph.v1.models.utils_color_pair_result import UtilsColorPairResult as UtilsColorPairResult
from neurograph.v1.models.utils_validation_error import UtilsValidationError as UtilsValidationError
from neurograph.v1.models.utils_validation_errors import UtilsValidationErrors as UtilsValidationErrors
from neurograph.v1.models.workbench_workbench_url_check_request import WorkbenchWorkbenchUrlCheckRequest as WorkbenchWorkbenchUrlCheckRequest
from neurograph.v1.models.workbench_workbench_url_check_response import WorkbenchWorkbenchUrlCheckResponse as WorkbenchWorkbenchUrlCheckResponse
from neurograph.v1.models.workbench_workbench_version import WorkbenchWorkbenchVersion as WorkbenchWorkbenchVersion
from neurograph.v1.models.workbench_workbench_version_many_response import WorkbenchWorkbenchVersionManyResponse as WorkbenchWorkbenchVersionManyResponse
from neurograph.v1.models.workbench_workbench_version_response import WorkbenchWorkbenchVersionResponse as WorkbenchWorkbenchVersionResponse
from neurograph.v1.models.workbench_workbench_version_upsert_request import WorkbenchWorkbenchVersionUpsertRequest as WorkbenchWorkbenchVersionUpsertRequest




# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_buyer_scenario import ReportingBuyerScenario

class TestReportingBuyerScenario(unittest.TestCase):
    """ReportingBuyerScenario unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingBuyerScenario:
        """Test ReportingBuyerScenario
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingBuyerScenario`
        """
        model = ReportingBuyerScenario()
        if include_optional:
            return ReportingBuyerScenario(
                color = '',
                complexity = '',
                description = '',
                icon = '',
                id = '',
                intent = '',
                persona_context = '',
                persona_id = '',
                purchase_likelihood = 1.337,
                tags = [
                    ''
                    ],
                timeline = '',
                title = '',
                trigger_event = ''
            )
        else:
            return ReportingBuyerScenario(
        )
        """

    def testReportingBuyerScenario(self):
        """Test ReportingBuyerScenario"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.reports_api import ReportsApi


class TestReportsApi(unittest.TestCase):
    """ReportsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ReportsApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_public_reports_id_get(self) -> None:
        """Test case for api_v1_public_reports_id_get

        Get Public Report
        """
        pass

    def test_api_v1_reports_facets_get(self) -> None:
        """Test case for api_v1_reports_facets_get

        Get Report Facets
        """
        pass

    def test_api_v1_reports_generate_post(self) -> None:
        """Test case for api_v1_reports_generate_post

        Generate Report via Agent
        """
        pass

    def test_api_v1_reports_get(self) -> None:
        """Test case for api_v1_reports_get

        List Report Artifacts
        """
        pass

    def test_api_v1_reports_id_agent_status_get(self) -> None:
        """Test case for api_v1_reports_id_agent_status_get

        Get Agent Report Status
        """
        pass

    def test_api_v1_reports_id_delete(self) -> None:
        """Test case for api_v1_reports_id_delete

        Delete Report Artifact
        """
        pass

    def test_api_v1_reports_id_generate_summary_post(self) -> None:
        """Test case for api_v1_reports_id_generate_summary_post

        Generate Report Summary
        """
        pass

    def test_api_v1_reports_id_get(self) -> None:
        """Test case for api_v1_reports_id_get

        Get Report Artifact
        """
        pass

    def test_api_v1_reports_id_markdown_get(self) -> None:
        """Test case for api_v1_reports_id_markdown_get

        Get Report Markdown
        """
        pass

    def test_api_v1_reports_id_markdown_put(self) -> None:
        """Test case for api_v1_reports_id_markdown_put

        Update Report Markdown
        """
        pass

    def test_api_v1_reports_id_og_image_get(self) -> None:
        """Test case for api_v1_reports_id_og_image_get

        Get Report OG Image
        """
        pass

    def test_api_v1_reports_id_put(self) -> None:
        """Test case for api_v1_reports_id_put

        Update Report Artifact
        """
        pass

    def test_api_v1_reports_id_regenerate_og_image_post(self) -> None:
        """Test case for api_v1_reports_id_regenerate_og_image_post

        Regenerate Report OG Image
        """
        pass

    def test_api_v1_reports_id_share_get(self) -> None:
        """Test case for api_v1_reports_id_share_get

        Get Report Share Link
        """
        pass

    def test_api_v1_reports_id_sync_agent_post(self) -> None:
        """Test case for api_v1_reports_id_sync_agent_post

        Sync Agent Report Results
        """
        pass

    def test_api_v1_reports_post(self) -> None:
        """Test case for api_v1_reports_post

        Create Report Artifact
        """
        pass

    def test_api_v1_reports_search_get(self) -> None:
        """Test case for api_v1_reports_search_get

        Search Report Artifacts
        """
        pass

    def test_share_report_id_get(self) -> None:
        """Test case for share_report_id_get

        Get Report OG Meta
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.signal_client_signal_details_response import SignalClientSignalDetailsResponse

class TestSignalClientSignalDetailsResponse(unittest.TestCase):
    """SignalClientSignalDetailsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SignalClientSignalDetailsResponse:
        """Test SignalClientSignalDetailsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SignalClientSignalDetailsResponse`
        """
        model = SignalClientSignalDetailsResponse()
        if include_optional:
            return SignalClientSignalDetailsResponse(
                cached = True,
                client_info = neurograph.v1.models.signal/client_info.signal.ClientInfo(
                    client_uid = '', 
                    domain = '', 
                    org_uid = '', ),
                daily_intent = [
                    neurograph.v1.models.signal/daily_intent_band.signal.DailyIntentBand(
                        avg_attention_seconds = 1.337, 
                        avg_engagement_score = 1.337, 
                        avg_pages_viewed = 1.337, 
                        avg_predicted_probability = 1.337, 
                        conversion_rate = 1.337, 
                        converted_visitors = 56, 
                        date = '', 
                        intent_band = '', 
                        visitor_count = 56, )
                    ],
                daily_purchases = [
                    neurograph.v1.models.signal/daily_purchase_metrics.signal.DailyPurchaseMetrics(
                        api_success_count = 56, 
                        api_success_rate = 1.337, 
                        avg_data_completeness = 1.337, 
                        avg_order_value = 1.337, 
                        date = '', 
                        new_customers = 56, 
                        predicted_revenue = 1.337, 
                        returning_customers = 56, 
                        total_purchases = 56, 
                        total_revenue = 1.337, )
                    ],
                date_range = neurograph.v1.models.signal/date_range.signal.DateRange(
                    end_date = '', 
                    start_date = '', ),
                error = '',
                persona_breakdown = [
                    neurograph.v1.models.signal/persona_conversion.signal.PersonaConversion(
                        avg_match_likelihood = 1.337, 
                        persona_name = '', 
                        purchase_count = 56, 
                        return_rate = 1.337, 
                        returning_count = 56, 
                        revenue = 1.337, )
                    ],
                query_time_ms = 56,
                totals = neurograph.v1.models.signal/client_signal_totals.signal.ClientSignalTotals(
                    conversions = neurograph.v1.models.signal/conversion_summary.signal.ConversionSummary(
                        api_success_rate = 1.337, 
                        avg_data_completeness = 1.337, 
                        new_customers = 56, 
                        predicted_revenue = 1.337, 
                        prediction_uplift_pct = 1.337, 
                        returning_customers = 56, 
                        returning_pct = 1.337, 
                        total_purchases = 56, 
                        total_revenue = 1.337, ), 
                    intent = neurograph.v1.models.signal/intent_summary.signal.IntentSummary(
                        avg_high_engagement = 1.337, 
                        avg_low_engagement = 1.337, 
                        avg_medium_engagement = 1.337, 
                        high_conversion_rate = 1.337, 
                        low_conversion_rate = 1.337, 
                        medium_conversion_rate = 1.337, 
                        total_high = 56, 
                        total_low = 56, 
                        total_medium = 56, ), )
            )
        else:
            return SignalClientSignalDetailsResponse(
        )
        """

    def testSignalClientSignalDetailsResponse(self):
        """Test SignalClientSignalDetailsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_persona_buyer_scenarios_response import ReportingPersonaBuyerScenariosResponse

class TestReportingPersonaBuyerScenariosResponse(unittest.TestCase):
    """ReportingPersonaBuyerScenariosResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingPersonaBuyerScenariosResponse:
        """Test ReportingPersonaBuyerScenariosResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingPersonaBuyerScenariosResponse`
        """
        model = ReportingPersonaBuyerScenariosResponse()
        if include_optional:
            return ReportingPersonaBuyerScenariosResponse(
                cached = True,
                error = '',
                meta = neurograph.v1.models.reporting/buyer_scenarios_meta.reporting.BuyerScenariosMeta(
                    client_id = '', 
                    data_date = '', 
                    generated_at = '', ),
                query_time_ms = 56,
                scenarios = [
                    neurograph.v1.models.reporting/buyer_scenario.reporting.BuyerScenario(
                        color = '', 
                        complexity = '', 
                        description = '', 
                        icon = '', 
                        id = '', 
                        intent = '', 
                        persona_context = '', 
                        persona_id = '', 
                        purchase_likelihood = 1.337, 
                        tags = [
                            ''
                            ], 
                        timeline = '', 
                        title = '', 
                        trigger_event = '', )
                    ],
                total_count = 56
            )
        else:
            return ReportingPersonaBuyerScenariosResponse(
        )
        """

    def testReportingPersonaBuyerScenariosResponse(self):
        """Test ReportingPersonaBuyerScenariosResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reports_report_generate_request import ReportsReportGenerateRequest

class TestReportsReportGenerateRequest(unittest.TestCase):
    """ReportsReportGenerateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportsReportGenerateRequest:
        """Test ReportsReportGenerateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportsReportGenerateRequest`
        """
        model = ReportsReportGenerateRequest()
        if include_optional:
            return ReportsReportGenerateRequest(
                analysis_type = 'cross_persona',
                brand_context = { },
                client_id = 'cli_4o5o5ENX3q3e8oosqlBKF7',
                custom_prompt = '',
                data_sources = [
                    neurograph.v1.models.reports/data_source_config.reports.DataSourceConfig(
                        client_id = 'cli_4o5o5ENX3q3e8oosqlBKF7', 
                        dataset_id = '', 
                        end_date = '2026-01-01', 
                        file_path = '', 
                        project_id = '', 
                        query = '', 
                        start_date = '2025-12-01', 
                        table_id = '', 
                        type = 'neurograph_pipeline', )
                    ],
                date_range = neurograph.v1.models.reports/date_range.reports.DateRange(
                    end = '2026-01-01', 
                    start = '2025-12-01', ),
                end_date = '2026-01-01',
                max_rows = 100000,
                name = 'Q4 2025 Cross-Persona Analysis',
                output_format = 'json',
                personas = [
                    ''
                    ],
                report_type = 'Cross-Persona Product Analysis',
                start_date = '2025-12-01'
            )
        else:
            return ReportsReportGenerateRequest(
        )
        """

    def testReportsReportGenerateRequest(self):
        """Test ReportsReportGenerateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_persona_demographics_response import ReportingPersonaDemographicsResponse

class TestReportingPersonaDemographicsResponse(unittest.TestCase):
    """ReportingPersonaDemographicsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingPersonaDemographicsResponse:
        """Test ReportingPersonaDemographicsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingPersonaDemographicsResponse`
        """
        model = ReportingPersonaDemographicsResponse()
        if include_optional:
            return ReportingPersonaDemographicsResponse(
                age_distribution = neurograph.v1.models.reporting/age_distribution_data.reporting.AgeDistributionData(
                    buckets = [
                        neurograph.v1.models.reporting/age_bucket.reporting.AgeBucket(
                            avg_pct = 1.337, 
                            bucket = '', 
                            comparison = '', 
                            customer_count = 56, 
                            delta = 1.337, 
                            percentage = 1.337, )
                        ], ),
                cached = True,
                error = '',
                gender_split = neurograph.v1.models.reporting/gender_split_data.reporting.GenderSplitData(
                    dominant_gender = '', 
                    female_count = 56, 
                    female_pct = 56, 
                    male_count = 56, 
                    male_pct = 56, 
                    total_count = 56, 
                    unknown_count = 56, ),
                geographic_distribution = neurograph.v1.models.reporting/geographic_distribution_data.reporting.GeographicDistributionData(
                    metro_areas = [
                        neurograph.v1.models.reporting/metro_area.reporting.MetroArea(
                            concentration_pct = 1.337, 
                            customer_count = 56, 
                            delta = 1.337, 
                            metro = '', 
                            rank = 56, 
                            state = '', )
                        ], 
                    other_markets = neurograph.v1.models.reporting/other_markets.reporting.OtherMarkets(
                        concentration_pct = 1.337, 
                        count = 56, 
                        customer_count = 56, ), ),
                income_bands = neurograph.v1.models.reporting/income_bands_data.reporting.IncomeBandsData(
                    bands = [
                        neurograph.v1.models.reporting/income_band.reporting.IncomeBand(
                            band = '', 
                            customer_count = 56, 
                            label = '', 
                            percentage = 1.337, )
                        ], ),
                meta = neurograph.v1.models.reporting/demographics_meta.reporting.DemographicsMeta(
                    client_uid = '', 
                    computed_metrics = neurograph.v1.models.reporting/computed_metrics.reporting.ComputedMetrics(
                        median_age = 1.337, 
                        median_income = 56, ), 
                    generated_at = '', 
                    organization_uid = '', 
                    partition_date = '', 
                    persona_id = '', 
                    persona_name = '', 
                    sample_size = 56, ),
                query_time_ms = 56
            )
        else:
            return ReportingPersonaDemographicsResponse(
        )
        """

    def testReportingPersonaDemographicsResponse(self):
        """Test ReportingPersonaDemographicsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from neurograph.v1.models.reporting_daily_predictions import ReportingDailyPredictions
from neurograph.v1.models.reporting_date_range import ReportingDateRange
from neurograph.v1.models.reporting_model_job_stats import ReportingModelJobStats
from neurograph.v1.models.reporting_model_job_summary import ReportingModelJobSummary
from neurograph.v1.models.reporting_model_jobs_over_time import ReportingModelJobsOverTime
from neurograph.v1.models.reporting_model_version_stats import ReportingModelVersionStats
from typing import Optional, Set
from typing_extensions import Self

class ReportingModelInsightsResponse(BaseModel):
    """
    ReportingModelInsightsResponse
    """ # noqa: E501
    cached: Optional[StrictBool] = None
    daily_predictions: Optional[List[ReportingDailyPredictions]] = None
    date_range: Optional[ReportingDateRange] = None
    error: Optional[StrictStr] = None
    jobs_over_time: Optional[List[ReportingModelJobsOverTime]] = None
    query_time_ms: Optional[StrictInt] = None
    recent_jobs: Optional[List[ReportingModelJobSummary]] = None
    stats: Optional[ReportingModelJobStats] = None
    version_stats: Optional[List[ReportingModelVersionStats]] = None
    __properties: ClassVar[List[str]] = ["cached", "daily_predictions", "date_range", "error", "jobs_over_time", "query_time_ms", "recent_jobs", "stats", "version_stats"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReportingModelInsightsResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in daily_predictions (list)
        _items = []
        if self.daily_predictions:
            for _item_daily_predictions in self.daily_predictions:
                if _item_daily_predictions:
                    _items.append(_item_daily_predictions.to_dict())
            _dict['daily_predictions'] = _items
        # override the default output from pydantic by calling `to_dict()` of date_range
        if self.date_range:
            _dict['date_range'] = self.date_range.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in jobs_over_time (list)
        _items = []
        if self.jobs_over_time:
            for _item_jobs_over_time in self.jobs_over_time:
                if _item_jobs_over_time:
                    _items.append(_item_jobs_over_time.to_dict())
            _dict['jobs_over_time'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in recent_jobs (list)
        _items = []
        if self.recent_jobs:
            for _item_recent_jobs in self.recent_jobs:
                if _item_recent_jobs:
                    _items.append(_item_recent_jobs.to_dict())
            _dict['recent_jobs'] = _items
        # override the default output from pydantic by calling `to_dict()` of stats
        if self.stats:
            _dict['stats'] = self.stats.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in version_stats (list)
        _items = []
        if self.version_stats:
            for _item_version_stats in self.version_stats:
                if _item_version_stats:
                    _items.append(_item_version_stats.to_dict())
            _dict['version_stats'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReportingModelInsightsResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "cached": obj.get("cached"),
            "daily_predictions": [ReportingDailyPredictions.from_dict(_item) for _item in obj["daily_predictions"]] if obj.get("daily_predictions") is not None else None,
            "date_range": ReportingDateRange.from_dict(obj["date_range"]) if obj.get("date_range") is not None else None,
            "error": obj.get("error"),
            "jobs_over_time": [ReportingModelJobsOverTime.from_dict(_item) for _item in obj["jobs_over_time"]] if obj.get("jobs_over_time") is not None else None,
            "query_time_ms": obj.get("query_time_ms"),
            "recent_jobs": [ReportingModelJobSummary.from_dict(_item) for _item in obj["recent_jobs"]] if obj.get("recent_jobs") is not None else None,
            "stats": ReportingModelJobStats.from_dict(obj["stats"]) if obj.get("stats") is not None else None,
            "version_stats": [ReportingModelVersionStats.from_dict(_item) for _item in obj["version_stats"]] if obj.get("version_stats") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.openai_generated_brand import OpenaiGeneratedBrand

class TestOpenaiGeneratedBrand(unittest.TestCase):
    """OpenaiGeneratedBrand unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OpenaiGeneratedBrand:
        """Test OpenaiGeneratedBrand
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OpenaiGeneratedBrand`
        """
        model = OpenaiGeneratedBrand()
        if include_optional:
            return OpenaiGeneratedBrand(
                accessibility = neurograph.v1.models.openai/accessibility_info.openai.AccessibilityInfo(
                    contrast_ratios = {
                        'key' : 1.337
                        }, 
                    notes = '', 
                    passes = '', ),
                analysis = neurograph.v1.models.openai/brand_analysis.openai.BrandAnalysis(
                    design_style = '', 
                    industry_fit = '', 
                    personality = [
                        ''
                        ], ),
                colors = neurograph.v1.models.openai/brand_colors.openai.BrandColors(
                    color1 = '', 
                    color2 = '', 
                    color3 = '', 
                    color4 = '', 
                    color5 = '', 
                    primary_color = '', 
                    secondary_color = '', 
                    tertiary_color = '', ),
                reasoning = ''
            )
        else:
            return OpenaiGeneratedBrand(
        )
        """

    def testOpenaiGeneratedBrand(self):
        """Test OpenaiGeneratedBrand"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
